


/**************    This simulation file runs axisymmetric viscous cylindrical filament subjected to time periodic body force in Basilisk open source code(http://basilisk.fr). We have square domain with cylinder along axis of symmetry of fluid1 and outside as fluid2. 
The code solves two phase flow using VOF method. *********/



# include "axi.h"  				//Axi module
#include "navier-stokes/centered.h"
#include "two-phase.h"
#include "tension.h"
#include "vtk.h"


#define FILTERED
double k = 4.8;					//Wavenumber along z
# define length_domain (2*M_PI/k)*1	//Domain length of one wavelength
# define radius 0.2						//Radius of cylinder R0

double omega = 600.0*M_PI;		// Forcing frequency
int grid_size = 512;				// Initial uniform grid refinement 
double amp = 1.8e04;				// Forcing amplitude



/*** Boundary condition of outflow at top wall *******/
  u.t[top] = neumann(0);
  u.n[top] = neumann(0);
  p[top] = dirichlet(0);
 


int main() {

  /**
  We set the density and viscosity of each phase as well as the
  surface tension coefficient  */	
	
	
  rho1 = 0.957, mu1 = 0.1;

  rho2 = 0.001, mu2 = 0.001, f.sigma = 20.7;
  size (length_domain);
  init_grid (grid_size);
  periodic(right);       


  TOLERANCE = 1e-6;
  run();
}

event init (t = 0) {


 if (!restore ("restart"))
  fraction (f, -(y-radius-0.001*cos(k*x)));     
}



event acceleration (i++) {
  face vector av = a;
  foreach_face(y){
  
	  av.y[] = -(g + amp*cos(omega*t))*(y/radius);    // Define perturbed cylinder
	
}
}
	

event logfile (i++) {

  
  if(pid()==0){ 
  printf ("%g %g \n", t,dt);
 }
	
	  
	
}




/**** Output data*******/

event tecplot_data  (t=0;  t+=0.001; t<=20.0) {

  
	scalar vorticity[];
 	 foreach()
	vorticity[] = ((u.y[1,0] - u.y[-1,0]) - (u.x[0,1] - u.x[0,-1] ))/(2.*Delta);
  	
	char name[80];
	
	sprintf (name, "./data/nsdata-%g.vtk", t*1000.0); // make integral values of time to have a group data se
	FILE *file;
	file  = fopen(name,"w");
	
	output_vtk ({u,p,f,vorticity}, grid_size, file,0);
	fclose(file);

	 
	 char name2[80];

	 sprintf (name2, "./interface_data/line-%g.dat",t*1000.0);
	 FILE *file2;
	 file2 = fopen(name2,"w"); 
	 output_facets(f,file2);
	 fclose(file2);
	
	
}




event snapshot (t=0;  t+=0.001; t<=20.0) {

  dump ("restart");
  
}

/*
event adapt (i++) {
	
  adapt_wavelet ({f,u}, (double[]){1e-4,0.02,0.02},11,9);
	
  
}
*/






