
%% stability chart -  Subharmonic (alpha = omega/2) 
%% The idea of generating stability chart is same as discussed in Patankar et. al 2018.

%% This script file is used to find (k,h) for m=0 axisymmetric case.



clear all;
close all;
clc;

%% Physical parameters of the system.


gamma = 20.7;      % Surface tension
rho = 0.957;       % Density of inner fluid
eta = 0.1;          % Dynamic viscosity of inner fluid
nu = eta/rho;
R0 = 0.2;           %Radius of cylindrical filament
sigma = 0;          % Set growth rate to zero in Floquet exponent to find nuetral stability curves
omega = 600*pi;     % Forcing frequency
alpha = omega/2;    % For Subharmonic case
ahat = [];
acbyg = [];
a = [];
N = 30;             % Number of terms in fourier expansion 

for k = 36     % Wave number range
n = 0:1:N;
j = sqrt(k^2 + (sigma + 1i*(alpha + n*omega))/nu);
A = [];
for  i = 1:N+1

% Expression for A matrix when m=0.   
    
    
A(i) = [[[[2.*k.^(-3).*1.*rho.^(-1).*(k.^3.*((-1).*k.^2+R0.^(-2)).*gamma+ ...
  2.*j(i).*k.^5.*(j(i).^2+(-1).*k.^2).^(-1).*eta.*(sqrt(-1).*alpha+sigma+sqrt( ...
  -1).*n(i).*omega).*besseli(1,j(i).*R0).^(-1).*(besseli(0,j(i).*R0)+ ...
  besseli(2,j(i).*R0))+sqrt(-1).*(j(i).^2+(-1).*k.^2).^(-1).*(j(i).^2+ ...
  k.^2).*eta.*(alpha+(sqrt(-1)*(-1)).*sigma+n(i).*omega).*besseli(1,k.*R0).^( ...
  -1).*(k.*((-1).*j(i).^2+k.^2).*R0.^(-1).*besseli(1,k.*R0)+( ...
  -1/2).*k.^2.*(j(i).^2+k.^2).*(besseli(0,k.*R0)+besseli(2,k.*R0) ...
  )))]]]];




end
B = zeros(2*N+2,2*N+2);
C = zeros(2*N+2,2*N+2);
B(1,1) = 1;
B(2,2) = -1;
B(1,3) = 1;
B(2,4) = 1;
j = 1;
i = 3;
for z = 1:2*N

B(i,j) = 1;
B(i,j+4) = 1;
i = i+1;
j = j+1;
if j>2*N-2
     B(i,j) = 1;
     B(i+1,j+1) = 1;
    break
end
end
z = 1;
for i = 1:2:2*N+2 
   C(i,i) = real(A(z));
   C(i+1,i+1) = C(i,i);
    C(i+1,i) = imag(A(z));
   C(i,i+1) = -imag(A(z));
   z = z+1;
end

%% Generalized eigen value problem solver in matlab
[V,D] = eig(C,B);

%% Sorting and arranging real eigen values in increasing order
tf = isreal(D);
if tf
M = [];
M = max(D);
M = sort(M);
M = M(M>0);
a = (M);

acbyg = [acbyg ;a];
else
   E = [];
   for i =1:2*N+2
       for j=1:2*N+2
            if imag(D(i,j))==0
                E = [E real(D(i,j))];
                E = E(E>0);
            end
        end
   end
  E = sort(E);
 ahat  = E;
y= length(E);
G = nan(1,N+1);
a = (E);

G = [a(1:y) G(y+1:end)];
acbyg = [acbyg ; G];

end

k

end

%% Plotting the nuetral stability curve for Subharmonic case
k = 0.1:0.1:100;
p = []; q =[];
for i = 1:length(k)
for j = 1:N+1 
    
    p = [p k(i)];
    q = [q acbyg(i,j)];
    
 end
end
plot(p,q,'k.');
axis([0 30 0 2000]);
save('SH_cyl');     % Save data of Subharmonic case

