(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    404070,       6964]
NotebookOptionsPosition[    399551,       6896]
NotebookOutlinePosition[    399890,       6911]
CellTagsIndexPosition[    399847,       6908]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "FixedTalbotNumericalLaplaceInversion.m"}], 
  "                     ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Keep", " ", "this", " ", "numerical", " ", "laplace", " ", "inversion", 
    " ", "matlab", " ", "file"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"We", " ", "solve", " ", "the", " ", "Axisymmetric", 
     RowBox[{"(", 
      RowBox[{"m", "=", "0"}], ")"}], " ", "integro", " ", "differential", 
     " ", "equation", 
     RowBox[{"(", "IDE", ")"}], " ", 
     RowBox[{"numerically", ".", " ", "First"}], " ", "we", " ", "define", 
     " ", "the", " ", "physical", " ", "parameters", " ", "of", " ", "the", 
     " ", "system", " ", "along", " ", "with", " ", "the", " ", "different", 
     " ", "terms", " ", "in", " ", 
     RowBox[{"IDE", ".", " ", "At"}], " ", "first", " ", "the", " ", 
     "initial", " ", "guess", " ", "is", " ", "given", " ", "by", " ", 
     "solving", " ", "the", " ", "IDE", " ", "without", " ", "integral", " ", 
     
     RowBox[{"terms", ".", " ", "The"}], " ", "unknown", " ", "laplace", " ", 
     "inverse", " ", "terms", " ", "are", " ", "calculated", " ", 
     RowBox[{"numerically", ".", " ", "Now"}]}], ",", " ", 
    RowBox[{
    "we", " ", "solve", " ", "the", " ", "complete", " ", "IDE", " ", 
     "iteratively", " ", "to", " ", "find", " ", "such", " ", "an", " ", 
     "amplitude", " ", "a", 
     RowBox[{"(", "t", ")"}], " ", "where", " ", "error", " ", "is", " ", 
     "below", " ", "tolerance", " ", "for", " ", "two", " ", "succesive", " ", 
     RowBox[{"iterations", "."}]}]}], "    ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Defining", " ", "physical", " ", "parameters", " ", "of", " ", "the", " ", 
    RowBox[{"system", "."}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{
  3.801393072728484*^9, {3.801393135503572*^9, 3.801393150132546*^9}, {
   3.845101166950863*^9, 3.845101239083713*^9}},
 FontSize->24,ExpressionUUID->"5171e089-ec43-4ae7-9b36-e4b41d7c73d7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"k", " ", "=", "4.8"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Wavenumber", " ", "in", " ", "Z", " ", "direction"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", " ", "=", " ", "0"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Wavenumber", " ", "in", " ", "\[Theta]", " ", "direction"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", " ", "=", "0.957"}], ";"}], 
  RowBox[{"(*", " ", "Density", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]", " ", "=", " ", "0.1"}], ";"}], 
  RowBox[{"(*", " ", "Viscosity", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", " ", "=", " ", 
   RowBox[{"\[Mu]", "/", "\[Rho]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", " ", "=", "20.7"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Surface", " ", "tension"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R", " ", "=", " ", "0.2"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Radius", " ", "of", " ", "cylinder"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", " ", "=", 
    RowBox[{"1.8", "*", 
     SuperscriptBox["10", "4"]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Forcing", " ", "amplitude"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalOmega]", " ", "=", " ", 
    RowBox[{"600", "\[Pi]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Forcing", " ", "frequency"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ti", "=", "0.001"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Inital", " ", 
    RowBox[{"time", "/", "Start"}], " ", "time"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dt", "=", "0.001"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"time", " ", "step"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tf", "=", "3"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Final", " ", 
    RowBox[{"time", "/", "end"}], " ", "time"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"l", "[", "s_", "]"}], ":=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", 
        FractionBox["s", "\[Nu]"]}], ")"}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Bessel", " ", "functions", " ", "and", " ", "their", " ", "derivatives"}],
    " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.77659049045436*^9, 3.776590494093211*^9}, {
   3.776600095831539*^9, 3.7766000960274973`*^9}, {3.7766522224530907`*^9, 
   3.77665224166*^9}, {3.776652661623063*^9, 3.776652687745159*^9}, {
   3.7766527461069393`*^9, 3.776652753456828*^9}, {3.776654798788138*^9, 
   3.776654798989636*^9}, {3.776657219566195*^9, 3.7766572199079323`*^9}, 
   3.7766579329880743`*^9, 3.776658359105706*^9, {3.776658656727878*^9, 
   3.776658658604164*^9}, 3.7766590819005833`*^9, 3.7766591479091063`*^9, 
   3.776659278055718*^9, {3.776685962452806*^9, 3.776685962650222*^9}, {
   3.7766861687911386`*^9, 3.776686169409986*^9}, {3.776688379837984*^9, 
   3.7766883807635937`*^9}, {3.7766887096850157`*^9, 3.776688710607897*^9}, {
   3.776688863935882*^9, 3.7766888653593807`*^9}, {3.776689426149911*^9, 
   3.776689427536786*^9}, {3.776689541343191*^9, 3.7766895735175123`*^9}, {
   3.7766896475132647`*^9, 3.7766896505000362`*^9}, {3.776689723787209*^9, 
   3.7766897285550547`*^9}, {3.776690017960464*^9, 3.776690025407716*^9}, {
   3.776690465282051*^9, 3.776690466385378*^9}, {3.7766906436726427`*^9, 
   3.776690663537575*^9}, {3.776690789711232*^9, 3.776690813167811*^9}, {
   3.7767369743178368`*^9, 3.776736975372403*^9}, {3.7767371752065077`*^9, 
   3.776737175677422*^9}, 3.776737235223464*^9, {3.779088008970264*^9, 
   3.779088052992144*^9}, 3.7800384280744963`*^9, {3.780112616247292*^9, 
   3.78011266825264*^9}, {3.780112764114499*^9, 3.7801127657307367`*^9}, 
   3.780112898213328*^9, {3.780126807492028*^9, 3.780126834151548*^9}, {
   3.780127148178914*^9, 3.7801271493301497`*^9}, 3.780127260434587*^9, {
   3.7801273132968483`*^9, 3.7801273138244534`*^9}, {3.780199590098336*^9, 
   3.780199590858077*^9}, 3.780220642583696*^9, {3.7809112423892612`*^9, 
   3.7809112435568457`*^9}, {3.7809121628336687`*^9, 3.780912163097327*^9}, {
   3.780912465770743*^9, 3.780912466010109*^9}, {3.7815064634413633`*^9, 
   3.7815064642812643`*^9}, {3.781584014733437*^9, 3.781584019676612*^9}, {
   3.781584241476307*^9, 3.781584244321802*^9}, 3.7815843364392033`*^9, {
   3.7833060575865183`*^9, 3.7833060890924664`*^9}, {3.7833065311044397`*^9, 
   3.783306550385255*^9}, {3.783306681524085*^9, 3.783306693564311*^9}, {
   3.7833067325767403`*^9, 3.783306732832395*^9}, {3.783307164747388*^9, 
   3.783307180306714*^9}, 3.78330724762978*^9, 3.7833072948899107`*^9, {
   3.783307345049576*^9, 3.783307345623934*^9}, {3.783307391273081*^9, 
   3.783307391646315*^9}, {3.78330744175128*^9, 3.783307441908577*^9}, {
   3.783307483316141*^9, 3.783307484507182*^9}, {3.7833075303289022`*^9, 
   3.783307530495802*^9}, {3.7833229410784407`*^9, 3.78332298866875*^9}, {
   3.7833230340272493`*^9, 3.783323034330513*^9}, {3.783323087162611*^9, 
   3.783323087665271*^9}, {3.783323323001086*^9, 3.7833233232884483`*^9}, {
   3.783323400692006*^9, 3.7833234037484694`*^9}, {3.783323456284779*^9, 
   3.783323456571496*^9}, {3.783323528653915*^9, 3.7833235299255743`*^9}, {
   3.783323575468367*^9, 3.783323578820448*^9}, {3.783323631115884*^9, 
   3.783323632506899*^9}, {3.783323674593576*^9, 3.783323675201199*^9}, {
   3.7833237261283216`*^9, 3.78332372732025*^9}, {3.783323769405966*^9, 
   3.783323769829404*^9}, {3.783323812626596*^9, 3.783323812923395*^9}, {
   3.783323854745332*^9, 3.783323854984583*^9}, {3.783323898895488*^9, 
   3.7833238991583147`*^9}, {3.783329855524795*^9, 3.783329876278758*^9}, {
   3.7833299312717237`*^9, 3.783329931590773*^9}, {3.783329973380328*^9, 
   3.78332997377136*^9}, {3.783330075995262*^9, 3.7833300764342833`*^9}, {
   3.7833306227892723`*^9, 3.783330649978549*^9}, {3.7833307841720333`*^9, 
   3.783330806214529*^9}, {3.7833308507169867`*^9, 3.7833308510296907`*^9}, {
   3.783330900556285*^9, 3.783330901467188*^9}, {3.783330946017191*^9, 
   3.783330946657832*^9}, {3.783332917337983*^9, 3.783332930754298*^9}, {
   3.783332987818001*^9, 3.783332988250154*^9}, {3.783333038065292*^9, 
   3.783333038761303*^9}, {3.783333083672214*^9, 3.7833330856716347`*^9}, {
   3.7833331301509027`*^9, 3.7833331307344923`*^9}, {3.78333317101159*^9, 
   3.783333171508696*^9}, {3.783333211217222*^9, 3.783333211848989*^9}, 
   3.783333250271098*^9, {3.7833332907966423`*^9, 3.783333292244582*^9}, {
   3.783333344093384*^9, 3.783333344597287*^9}, {3.783333384457428*^9, 
   3.7833333850336647`*^9}, {3.7833357161673183`*^9, 3.78333573311202*^9}, {
   3.783341452790267*^9, 3.783341453178082*^9}, {3.783394670161025*^9, 
   3.78339467147808*^9}, {3.7834032037666197`*^9, 3.783403221575508*^9}, {
   3.783403268221203*^9, 3.7834032707048197`*^9}, {3.783403313592342*^9, 
   3.783403314129593*^9}, {3.783403373826324*^9, 3.783403374387279*^9}, {
   3.783666181768031*^9, 3.783666181982954*^9}, {3.783666220506455*^9, 
   3.783666220746192*^9}, 3.785221403417355*^9, {3.78522586995502*^9, 
   3.785225870323247*^9}, {3.785225912904089*^9, 3.785225929626542*^9}, {
   3.785226179836712*^9, 3.7852261801320267`*^9}, 3.7852264802193747`*^9, {
   3.785226619829672*^9, 3.7852266216531963`*^9}, 3.785227179215004*^9, 
   3.7852273018871117`*^9, {3.785567773376718*^9, 3.785567778161352*^9}, {
   3.785638143588903*^9, 3.7856381664872913`*^9}, {3.785638288776905*^9, 
   3.785638289912362*^9}, {3.785638387678463*^9, 3.785638412128665*^9}, {
   3.7856384530063*^9, 3.7856384995247297`*^9}, {3.785638541659128*^9, 
   3.78563861590047*^9}, {3.785638866302928*^9, 3.785638866566554*^9}, {
   3.785639710488686*^9, 3.785639733995145*^9}, {3.7856603457896547`*^9, 
   3.785660346172991*^9}, {3.78580979620182*^9, 3.7858098180601397`*^9}, {
   3.7863473464812937`*^9, 3.7863473585946817`*^9}, {3.786347966044496*^9, 
   3.786347966619659*^9}, {3.786348057888895*^9, 3.78634808822815*^9}, {
   3.7863483176116133`*^9, 3.7863483216351557`*^9}, {3.786348362761746*^9, 
   3.786348391252617*^9}, {3.786349701369939*^9, 3.786349714476246*^9}, {
   3.786349773980876*^9, 3.7863497851899843`*^9}, {3.786353026750306*^9, 
   3.7863530351824617`*^9}, {3.7863539326484737`*^9, 3.786353936160111*^9}, {
   3.789223549655633*^9, 3.7892235564361153`*^9}, 3.7892656812584953`*^9, {
   3.789286889580023*^9, 3.789286891740407*^9}, 3.7892885998519697`*^9, {
   3.7898746212813053`*^9, 3.789874623185194*^9}, {3.789875631188958*^9, 
   3.7898756404280443`*^9}, {3.790319066809005*^9, 3.7903191142010117`*^9}, 
   3.791267940677094*^9, 3.791623162919319*^9, {3.8013931584245577`*^9, 
   3.80139317254949*^9}, {3.801453991746207*^9, 3.8014539919434557`*^9}, {
   3.801454645651969*^9, 3.801454683572372*^9}, {3.801464274336164*^9, 
   3.801464276754464*^9}, 3.801465217139464*^9, 3.80146526248067*^9, {
   3.801468140296259*^9, 3.801468150070155*^9}, {3.801469373381792*^9, 
   3.801469373970348*^9}, {3.801668470587489*^9, 3.801668472092754*^9}, {
   3.8016686023751583`*^9, 3.801668602968492*^9}, {3.801669022110284*^9, 
   3.801669022754127*^9}, {3.8016697487470837`*^9, 3.801669764923854*^9}, {
   3.801904830639818*^9, 3.801904836401939*^9}, 3.801905449609579*^9, 
   3.8019054863120117`*^9, {3.8022474326230583`*^9, 3.802247433396411*^9}, 
   3.802337837843046*^9, {3.802355691495283*^9, 3.802355692094493*^9}, {
   3.802421146106141*^9, 3.802421165003631*^9}, {3.802421989477386*^9, 
   3.802422011366*^9}, {3.802423790306855*^9, 3.8024237911547194`*^9}, {
   3.802424349331112*^9, 3.802424349960457*^9}, {3.8024248461486692`*^9, 
   3.802424877833399*^9}, 3.802426884146001*^9, {3.802516968738346*^9, 
   3.802516970550452*^9}, {3.802517001762198*^9, 3.802517020954843*^9}, 
   3.802517263338035*^9, {3.802517362744*^9, 3.80251736396452*^9}, 
   3.802517483228105*^9, {3.8025182098419447`*^9, 3.802518210061729*^9}, {
   3.802519424799716*^9, 3.8025194514510193`*^9}, {3.802519501416842*^9, 
   3.8025195028832493`*^9}, {3.8025195441891623`*^9, 3.8025195453100452`*^9}, 
   3.8025195911650047`*^9, {3.802519888249467*^9, 3.802519889191506*^9}, {
   3.8025200069099197`*^9, 3.802520010423931*^9}, {3.802520100004031*^9, 
   3.8025201066472187`*^9}, {3.802520203458818*^9, 3.802520211030436*^9}, 
   3.8025203699218807`*^9, 3.8025204199177437`*^9, {3.802520675811914*^9, 
   3.8025206786748323`*^9}, 3.802520950067223*^9, 3.802520999485489*^9, {
   3.802521077130741*^9, 3.802521081745576*^9}, {3.8025211836325903`*^9, 
   3.802521187651286*^9}, {3.802521218009177*^9, 3.802521218629352*^9}, 
   3.802521299269911*^9, {3.804304202329832*^9, 3.804304211795363*^9}, {
   3.804513420058659*^9, 3.804513420676937*^9}, 3.804513506328265*^9, {
   3.804513548641416*^9, 3.804513569428067*^9}, 3.8045146224799757`*^9, {
   3.806568822765375*^9, 3.806568840339107*^9}, {3.8065688872574*^9, 
   3.806568922577332*^9}, {3.806569396743195*^9, 3.806569397158071*^9}, {
   3.8066484372587833`*^9, 3.806648441272943*^9}, {3.806648886605508*^9, 
   3.8066488917073507`*^9}, {3.807361483212414*^9, 3.8073615035162354`*^9}, {
   3.8073615343344707`*^9, 3.807361556416737*^9}, {3.807373732110854*^9, 
   3.8073738369035063`*^9}, {3.807373905708324*^9, 3.807373999221177*^9}, {
   3.80829690233611*^9, 3.8082969079845467`*^9}, {3.808296985898477*^9, 
   3.8082970001802397`*^9}, {3.8082987132956047`*^9, 3.808298717124075*^9}, 
   3.8082987744115543`*^9, 3.808299008504508*^9, {3.808299200056425*^9, 
   3.808299200778974*^9}, {3.808299883654148*^9, 3.808299885281797*^9}, {
   3.808300158259301*^9, 3.80830017099054*^9}, 3.808300232926248*^9, {
   3.8083002683817587`*^9, 3.8083002779484253`*^9}, 3.8083004690142107`*^9, 
   3.808303205618739*^9, 3.808303679607313*^9, {3.808304129972933*^9, 
   3.808304137375615*^9}, 3.808305556520042*^9, {3.808305612038678*^9, 
   3.808305612893073*^9}, {3.808307306764553*^9, 3.8083073072973137`*^9}, 
   3.808314396842677*^9, 3.808314568638154*^9, {3.8084496423208103`*^9, 
   3.8084496463026867`*^9}, 3.808449918738695*^9, {3.8084554687322807`*^9, 
   3.8084554694359303`*^9}, {3.8084576130665894`*^9, 3.808457620748127*^9}, 
   3.8084604133741837`*^9, {3.8084690217592163`*^9, 3.808469048014056*^9}, {
   3.808474521929495*^9, 3.8084745451445932`*^9}, {3.8084805573372717`*^9, 
   3.808480562092709*^9}, 3.808481952578281*^9, 3.80848216259403*^9, 
   3.808484797854759*^9, {3.808496786916135*^9, 3.8084967876492968`*^9}, 
   3.808497049517077*^9, {3.8084970983628397`*^9, 3.808497099090567*^9}, 
   3.808537882968882*^9, {3.80853813214825*^9, 3.808538151268837*^9}, {
   3.808540249669509*^9, 3.8085402711755953`*^9}, {3.808540826180147*^9, 
   3.808540826404952*^9}, {3.808541109254578*^9, 3.80854110966152*^9}, {
   3.808541291739934*^9, 3.808541321953821*^9}, {3.8085670559851513`*^9, 
   3.808567059300318*^9}, {3.808568153575659*^9, 3.808568164861182*^9}, {
   3.808568197449216*^9, 3.8085681985330048`*^9}, {3.808568508684791*^9, 
   3.808568508972687*^9}, {3.808569533100862*^9, 3.808569533357394*^9}, {
   3.808569577668746*^9, 3.808569682703498*^9}, {3.808573963826037*^9, 
   3.808573969715666*^9}, {3.808757668258966*^9, 3.808757796783395*^9}, {
   3.808757828714321*^9, 3.808757836722381*^9}, {3.808758469922291*^9, 
   3.8087586527171793`*^9}, {3.808819462804134*^9, 3.808819486155414*^9}, {
   3.808821090660083*^9, 3.80882109175917*^9}, {3.808886107946096*^9, 
   3.8088861088248053`*^9}, {3.8089909936371098`*^9, 3.808991012099786*^9}, {
   3.844303885845158*^9, 3.844303887612391*^9}, {3.844303973486187*^9, 
   3.844303973765155*^9}, {3.844304929192058*^9, 3.844304935903275*^9}, {
   3.8443049719765453`*^9, 3.844304972528123*^9}, {3.844305885719862*^9, 
   3.844305918927452*^9}, {3.8443059721683483`*^9, 3.8443059755848017`*^9}, {
   3.84430684840166*^9, 3.8443068683794613`*^9}, {3.844310119353904*^9, 
   3.844310141297226*^9}, {3.845101247511653*^9, 3.845101351721672*^9}, {
   3.845101425162142*^9, 3.845101426136937*^9}, {3.846580996185402*^9, 
   3.846581037439986*^9}, 3.846581644248001*^9},
 FontSize->24,ExpressionUUID->"85473b9d-1979-4501-b199-72ad7b47a03a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"B", " ", "=", " ", 
  RowBox[{
   RowBox[{"BesselI", "[", 
    RowBox[{"m", ",", "kr"}], "]"}], "/.", 
   RowBox[{"kr", "\[Rule]", 
    RowBox[{"k", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"G", " ", "=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"BesselI", "[", 
        RowBox[{"m", ",", "kr"}], "]"}], ",", "kr"}], "]"}], ",", "kr"}], 
    "]"}], "/.", 
   RowBox[{"kr", "\[Rule]", 
    RowBox[{"k", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"T", " ", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"BesselI", "[", 
        RowBox[{"m", ",", "lr"}], "]"}], ",", "lr"}], "]"}], ",", "lr"}], 
    "]"}], "/.", 
   RowBox[{"lr", "\[Rule]", 
    RowBox[{"l", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Q", " ", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"BesselI", "[", 
      RowBox[{"m", ",", "lr"}], "]"}], ",", "lr"}], "]"}], "/.", 
   RowBox[{"lr", "\[Rule]", 
    RowBox[{"l", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"W", " ", "=", " ", 
  RowBox[{
   RowBox[{"BesselI", "[", 
    RowBox[{"m", ",", "lr"}], "]"}], "/.", 
   RowBox[{"lr", "\[Rule]", 
    RowBox[{"l", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", " ", "=", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"BesselI", "[", 
       RowBox[{"m", ",", "kr"}], "]"}], ",", "kr"}], "]"}], "/.", 
    RowBox[{"kr", "\[Rule]", 
     RowBox[{"k", " ", "R"}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Definations", " ", "of", " ", "different", " ", "terms", " ", "in", " ", 
    "IDE"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coeff1", " ", "=", 
   RowBox[{"2", "\[Nu]", " ", 
    SuperscriptBox["k", "2"], 
    RowBox[{"(", 
     RowBox[{"1", "+", " ", 
      FractionBox["G", "B"]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coeff2", " ", "=", " ", 
   FractionBox[
    RowBox[{"4", 
     SuperscriptBox["\[Nu]", "2"], " ", 
     SuperscriptBox["k", "4"]}], "B"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zeta", "[", "s_", "]"}], ":=", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["G", "s"], " ", "-", " ", 
     FractionBox[
      RowBox[{"l", " ", "P", " ", "T"}], 
      RowBox[{"k", " ", "s", " ", "Q"}]]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"omegasq", "=", 
   RowBox[{
    FractionBox["\[Gamma]", 
     RowBox[{"\[Rho]", " ", 
      SuperscriptBox["R", "3"]}]], 
    FractionBox[
     RowBox[{"k", " ", "R", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["k", "2"], 
         SuperscriptBox["R", "2"]}], " ", "+", " ", 
        SuperscriptBox["m", "2"], " ", "-", " ", "1"}], ")"}]}], 
     FractionBox["B", "P"]]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77659620817132*^9, 3.776596208492461*^9}, 
   3.780038545552227*^9, {3.780039512380299*^9, 3.780039535245902*^9}, 
   3.780039689643992*^9, 3.7800397702387123`*^9, {3.7801118619846373`*^9, 
   3.7801118899918823`*^9}, 3.780112165074728*^9, {3.7801126804664783`*^9, 
   3.7801127369746037`*^9}, {3.7801127790246964`*^9, 3.780112843725926*^9}, {
   3.780123450995088*^9, 3.780123507889742*^9}, {3.78012358806909*^9, 
   3.780123603902009*^9}, {3.780123705252776*^9, 3.780123846286627*^9}, {
   3.7801239042546167`*^9, 3.780124264163024*^9}, {3.780124309888632*^9, 
   3.7801243816428757`*^9}, {3.780124423953082*^9, 3.780124424592239*^9}, {
   3.780124465626055*^9, 3.780124588789979*^9}, {3.780124673396249*^9, 
   3.780124905785153*^9}, {3.780124953225955*^9, 3.780124976825972*^9}, {
   3.780125659678074*^9, 3.7801256671749153`*^9}, {3.780196719907235*^9, 
   3.780196740326442*^9}, {3.780223047379612*^9, 3.7802230787645187`*^9}, {
   3.7802231517296047`*^9, 3.7802231519981127`*^9}, {3.780223191484483*^9, 
   3.780223269405793*^9}, {3.780223352290498*^9, 3.780223355202455*^9}, {
   3.780299356978836*^9, 3.780299361518659*^9}, {3.7802994185555143`*^9, 
   3.780299526814056*^9}, {3.780299606817335*^9, 3.780299617394575*^9}, {
   3.78029979257024*^9, 3.780299794144471*^9}, 3.7802998399115267`*^9, {
   3.780303717991502*^9, 3.7803038601036873`*^9}, {3.7803039219358664`*^9, 
   3.780303952292893*^9}, {3.780303990431858*^9, 3.780303991135607*^9}, {
   3.780304973701988*^9, 3.7803050266432447`*^9}, {3.780305062445654*^9, 
   3.780305085924799*^9}, {3.7803069291476107`*^9, 3.7803069389960117`*^9}, {
   3.7803080063129377`*^9, 3.780308016536965*^9}, 3.780308117745068*^9, {
   3.78091115328384*^9, 3.780911189623518*^9}, {3.780911329995077*^9, 
   3.780911333186841*^9}, {3.780911551318634*^9, 3.780911721734528*^9}, {
   3.780912079679653*^9, 3.7809120890564547`*^9}, {3.780912414132848*^9, 
   3.780912441416415*^9}, {3.780912967899218*^9, 3.7809130025154943`*^9}, {
   3.780913343939293*^9, 3.780913359237755*^9}, {3.781096031884368*^9, 
   3.781096049219591*^9}, {3.781583063982914*^9, 3.781583064427458*^9}, {
   3.781583117286367*^9, 3.781583118028022*^9}, {3.785567812086453*^9, 
   3.785567850731534*^9}, 3.785567884600685*^9, 3.785568090084074*^9, 
   3.785568144235363*^9, 3.785568177360153*^9, 3.785568210660099*^9, 
   3.785568283854086*^9, 3.7855683292202806`*^9, 3.785568523783058*^9, {
   3.78556874185264*^9, 3.785568770687805*^9}, {3.7855692271738033`*^9, 
   3.785569244766614*^9}, {3.785569293477805*^9, 3.785569301974248*^9}, {
   3.785571238888652*^9, 3.7855712404893103`*^9}, {3.785571276397983*^9, 
   3.785571289199409*^9}, {3.7855713587103148`*^9, 3.785571361249198*^9}, {
   3.785571393750286*^9, 3.7855713950529737`*^9}, 3.7855715312085247`*^9, 
   3.801393083232232*^9, {3.801393126046955*^9, 3.801393130528103*^9}, {
   3.801393182961422*^9, 3.801393190927041*^9}, {3.801453981853961*^9, 
   3.8014539851262302`*^9}, {3.801454643139209*^9, 3.8014546786634817`*^9}, {
   3.8014642126352158`*^9, 3.80146425053855*^9}, {3.801464307287663*^9, 
   3.80146437864491*^9}, {3.801464441587782*^9, 3.8014645681488523`*^9}, {
   3.8014646456615562`*^9, 3.801464675671113*^9}, {3.8014649693821173`*^9, 
   3.801465087037052*^9}, {3.80146515147585*^9, 3.8014652054582233`*^9}, {
   3.801465237150055*^9, 3.801465273704183*^9}, {3.801465315408106*^9, 
   3.8014655477765217`*^9}, {3.801465795104253*^9, 3.801465861169879*^9}, {
   3.8014660036643467`*^9, 3.801466090745178*^9}, {3.8014661400960903`*^9, 
   3.8014662241387987`*^9}, {3.801466254657364*^9, 3.801466306625989*^9}, {
   3.8014676505945044`*^9, 3.801467811929215*^9}, {3.8014682893760777`*^9, 
   3.801468348136808*^9}, {3.801468432937935*^9, 3.8014684588995667`*^9}, {
   3.801468608837851*^9, 3.801468672407535*^9}, 3.8014690818129253`*^9, 
   3.8014705934813557`*^9, 3.801470653352488*^9, 3.801472840104603*^9, {
   3.8014731372280407`*^9, 3.8014731605169764`*^9}, {3.80147321431441*^9, 
   3.801473281754221*^9}, {3.8014825714670467`*^9, 3.80148259850628*^9}, {
   3.8015664323439693`*^9, 3.801566441294456*^9}, 3.801566919762183*^9, {
   3.801566967718417*^9, 3.801566970346084*^9}, {3.80162851637936*^9, 
   3.801628518156281*^9}, {3.801628720079422*^9, 3.80162874524076*^9}, {
   3.801628782927826*^9, 3.801628812540339*^9}, {3.801629256739462*^9, 
   3.801629272343095*^9}, {3.8016295449704657`*^9, 3.801629574510086*^9}, {
   3.80235217115522*^9, 3.802352181571389*^9}, {3.802352246512586*^9, 
   3.802352252755971*^9}, {3.802352359043069*^9, 3.802352363117859*^9}, {
   3.8023524760162354`*^9, 3.802352494186689*^9}, {3.802353140517479*^9, 
   3.802353267071307*^9}, {3.802415917671698*^9, 3.802415924194109*^9}, {
   3.802420038505086*^9, 3.802420067182438*^9}, {3.802420130055629*^9, 
   3.802420130949553*^9}, {3.802420184666218*^9, 3.802420258245195*^9}, {
   3.80242190914783*^9, 3.802421911120627*^9}, {3.802421951911088*^9, 
   3.8024219551501827`*^9}, {3.8024239783010273`*^9, 3.802424009442169*^9}, {
   3.8024246620055656`*^9, 3.8024246700283403`*^9}, {3.802424829006662*^9, 
   3.802424843764707*^9}, {3.808309895330728*^9, 3.8083099476699753`*^9}, {
   3.808474651002923*^9, 3.8084746513012447`*^9}, {3.808540325246036*^9, 
   3.808540326187664*^9}, {3.845101439959494*^9, 3.8451014457786407`*^9}, {
   3.846581273923324*^9, 3.84658131476501*^9}, {3.84658136667673*^9, 
   3.846581421750206*^9}, {3.846581480412465*^9, 3.846581490569216*^9}, {
   3.846581521303741*^9, 3.846581532054484*^9}, {3.846581647729248*^9, 
   3.846581698848308*^9}, {3.8465817661854887`*^9, 3.846581826432859*^9}, {
   3.846581994195722*^9, 3.846582006083169*^9}, {3.8465820565188704`*^9, 
   3.846582057075314*^9}, {3.846582100339909*^9, 3.8465821048435*^9}, {
   3.8465821392040577`*^9, 3.846582147790346*^9}},
 FontSize->24,ExpressionUUID->"09889190-8b07-487b-a6a7-bd08a73c21f0"],

Cell[BoxData["1.2440157162369516`"], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.846582366954022*^9},ExpressionUUID->"f9511c38-3b98-47a8-8bc7-\
1684ce0af0c7"],

Cell[BoxData["0.6841609159073996`"], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.846582366955364*^9},ExpressionUUID->"283af3ce-52a4-44f3-8322-\
09d90b3701f6"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"BesselI", "[", 
     RowBox[{"0", ",", 
      RowBox[{"0.2`", " ", "l"}]}], "]"}], "+", 
    RowBox[{"BesselI", "[", 
     RowBox[{"2", ",", 
      RowBox[{"0.2`", " ", "l"}]}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.846582366956583*^9},ExpressionUUID->"9027c40c-85b9-4812-9520-\
e1b873b2b1c7"],

Cell[BoxData[
 RowBox[{"BesselI", "[", 
  RowBox[{"1", ",", 
   RowBox[{"0.2`", " ", "l"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.8465823669578867`*^9},ExpressionUUID->"3fe623b6-8b9d-414b-8434-\
164dd963ee59"],

Cell[BoxData[
 RowBox[{"BesselI", "[", 
  RowBox[{"0", ",", 
   RowBox[{"0.2`", " ", "l"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.846582366959053*^9},ExpressionUUID->"e0006969-c3ce-4870-a137-\
037ceac0b4ef"],

Cell[BoxData["0.53746060831637`"], "Output",
 CellChangeTimes->{{3.846581768191781*^9, 3.846581780909429*^9}, 
   3.8465818284525137`*^9, 3.846581933889164*^9, 3.8465820178018217`*^9, {
   3.846582150988665*^9, 3.846582179721023*^9}, 3.846582264919149*^9, 
   3.8465823042117043`*^9, 
   3.846582366960163*^9},ExpressionUUID->"68fff86c-0634-4a30-936b-\
929b4c5c95e9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fun", "[", "s_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    FractionBox[
     RowBox[{"(", 
      RowBox[{"s", "+", "coeff1", " ", "+", " ", 
       RowBox[{"coeff2", "*", 
        RowBox[{"zeta", "[", "s", "]"}]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"coeff1", " ", "+", " ", 
          RowBox[{"coeff2", "*", 
           RowBox[{"zeta", "[", "s", "]"}]}]}], ")"}], "*", "s"}], " ", "+", 
       "omegasq"}], ")"}]], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7765963383400173`*^9, 3.776596343421032*^9}, {
   3.776596473449808*^9, 3.77659653463802*^9}, {3.776596609852038*^9, 
   3.7765966274740067`*^9}, 3.7765993189178267`*^9, {3.776599809416061*^9, 
   3.776599843178344*^9}, {3.776599877637339*^9, 3.7765998826871433`*^9}, {
   3.776652184617353*^9, 3.776652213846715*^9}, 3.780124971275868*^9, {
   3.780299538277485*^9, 3.780299543389999*^9}, {3.780299690962022*^9, 
   3.7802996943219347`*^9}, {3.780303870656625*^9, 3.780303872624042*^9}, {
   3.780911716133362*^9, 3.780911717028463*^9}, {3.781096053465014*^9, 
   3.7810960542019987`*^9}, {3.8014678370877438`*^9, 
   3.8014679265711927`*^9}, {3.801468069841428*^9, 3.801468109389173*^9}, 
   3.80146846085367*^9, {3.801469090105831*^9, 3.801469125329924*^9}, 
   3.801469243812356*^9, {3.801469287502347*^9, 3.801469308357257*^9}, 
   3.8014694037265253`*^9, {3.8014704222075987`*^9, 3.801470450290234*^9}, 
   3.8014707422377367`*^9, {3.801471606876046*^9, 3.801471610684855*^9}, 
   3.801472844196018*^9, {3.801482800536709*^9, 3.801482834667728*^9}, 
   3.801483491390717*^9, 3.8014836127830677`*^9, 3.801566788073718*^9, 
   3.801566929075046*^9, 3.801628533515827*^9, {3.8016288504464407`*^9, 
   3.8016288596524878`*^9}, 3.801630291459667*^9, 3.802421901258841*^9},
 FontSize->24,ExpressionUUID->"badeca00-a417-4ff1-a9cb-5e95feb1f0bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"t0", "=", 
    RowBox[{"Range", "[", 
     RowBox[{"ti", ",", "tf", ",", "dt"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.776596356518641*^9, 3.776596364639744*^9}, {
   3.780125145609284*^9, 3.780125177844348*^9}, {3.7801252369492397`*^9, 
   3.7801252379185553`*^9}, 3.780125504778492*^9, {3.7801255795575113`*^9, 
   3.780125580275215*^9}, 3.7801256268587847`*^9, 3.780125683369495*^9, {
   3.7801257271520147`*^9, 3.780125747226823*^9}, 3.78012582274868*^9, {
   3.7801259672876387`*^9, 3.7801259881934013`*^9}, {3.7801260243601294`*^9, 
   3.780126027159204*^9}, {3.780126101923004*^9, 3.7801261024183893`*^9}, {
   3.785220659021352*^9, 3.785220659252891*^9}, {3.8014699004634247`*^9, 
   3.8014699022846317`*^9}, {3.801470305947467*^9, 3.801470307632278*^9}, {
   3.801470368950068*^9, 3.801470387042385*^9}, {3.801470926173403*^9, 
   3.801470928605605*^9}, 3.801470973442585*^9, {3.8014711634366493`*^9, 
   3.801471165045319*^9}, {3.8014827914884043`*^9, 3.8014827973136253`*^9}, 
   3.8014828414008503`*^9, 3.801483633135948*^9, 3.801566392267994*^9, {
   3.801630283572638*^9, 3.8016303089111633`*^9}, {3.801630466356691*^9, 
   3.8016305636255913`*^9}, 3.8016307990160313`*^9, {3.801630863471937*^9, 
   3.801630925693514*^9}, {3.8016312428009167`*^9, 3.8016313084450912`*^9}, 
   3.8016313953760967`*^9, 3.8016357976161423`*^9, 3.801635915915111*^9, {
   3.8016359502745*^9, 3.801635951232521*^9}, {3.801636020126532*^9, 
   3.801636034432178*^9}, {3.801636076532216*^9, 3.801636102652957*^9}, {
   3.8016365031906643`*^9, 3.801636536507018*^9}, {3.8016365826813793`*^9, 
   3.801636593579726*^9}, {3.801636631038419*^9, 3.8016366364580173`*^9}, {
   3.801640429165882*^9, 3.801640432992828*^9}, {3.801640499076396*^9, 
   3.8016405023081427`*^9}, {3.801640641474802*^9, 3.8016406536147738`*^9}, {
   3.801640822609211*^9, 3.801640823803277*^9}, {3.801640855709111*^9, 
   3.801640919872559*^9}, {3.801657591674144*^9, 3.8016576049493628`*^9}, {
   3.8016580212203083`*^9, 3.80165802504309*^9}, {3.801658277886244*^9, 
   3.801658288479642*^9}, {3.801658615634491*^9, 3.8016586251227407`*^9}, {
   3.801660951979464*^9, 3.8016609920171328`*^9}, {3.801661544386126*^9, 
   3.8016615510794287`*^9}, 3.801663625296599*^9, 3.801666723151155*^9, {
   3.801666787466379*^9, 3.801666789038557*^9}, {3.8016673676504803`*^9, 
   3.801667368273942*^9}, 3.8016678859656467`*^9, {3.801668590441741*^9, 
   3.801668594871394*^9}, {3.801669793103066*^9, 3.801669806183701*^9}, {
   3.801905461356311*^9, 3.8019054967225313`*^9}, 3.802233738163259*^9, 
   3.802233794213666*^9, 3.802421894377265*^9, {3.8082995439778347`*^9, 
   3.8082995642935123`*^9}, {3.808300048896151*^9, 3.808300078389709*^9}, {
   3.8083002876707907`*^9, 3.808300294614984*^9}, 3.80853797437296*^9, {
   3.808540807748969*^9, 3.808540810998312*^9}, {3.845101449561963*^9, 
   3.845101452657915*^9}, 3.8451015156107397`*^9},
 FontSize->24,ExpressionUUID->"86989e75-c811-432b-a218-2e4062dc7931"],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"Guess", " ", "solution", " ", 
    StyleBox[
     RowBox[{
      StyleBox["with",
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"], "ou", 
      StyleBox["t",
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"]}]], 
    StyleBox[" ",
     FontFamily->"Source Code Pro",
     FontWeight->"Bold"], 
    StyleBox[
     RowBox[{
      StyleBox[
       StyleBox["i",
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"],
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"], "ntegral"}]], " ", 
    StyleBox["terms",
     FontFamily->"Source Code Pro",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontFamily->"Source Code Pro",
     FontWeight->"Bold"], 
    StyleBox[
     RowBox[{
      StyleBox["i",
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"], "n"}],
     FontFamily->"Source Code Pro",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontFamily->"Source Code Pro",
     FontWeight->"Bold"], 
    StyleBox[
     RowBox[{
      StyleBox[
       StyleBox["I",
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"],
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"], "DE"}]]}], " ", "*)"}],
  FontFamily->"Source Code Pro",
  FontWeight->"Bold"]], "Input",
 CellChangeTimes->{{3.780126125722629*^9, 3.780126125734283*^9}, 
   3.845101513513424*^9},
 FontSize->24,ExpressionUUID->"b0c8d03c-8236-4abd-a9fb-bbcc535ffbb1"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<NumericalCalculus`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7790884479666452`*^9, 3.7790884551185703`*^9}, 
   3.780125472132679*^9, 3.780126628900628*^9, {3.80242699863465*^9, 
   3.80242700102427*^9}},
 FontSize->24,ExpressionUUID->"599a8d82-97b7-4b2d-bd29-163f3c89f313"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"yig", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"omegasq", " ", "-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "h"}], " ", "k", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[CapitalOmega]", "*", "x"}], "]"}]}], 
         FractionBox["B", "P"]]}], ")"}]}], 
     RowBox[{"y", "[", "x", "]"}]}], "-", 
    RowBox[{"coeff1", "*", 
     RowBox[{
      RowBox[{"y", "'"}], "[", "x", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.776572031281805*^9, 3.7765720482829027`*^9}, {
   3.776572093430344*^9, 3.776572108130097*^9}, {3.7765746025790854`*^9, 
   3.776574603183268*^9}, 3.776580397955139*^9, {3.776581829255447*^9, 
   3.776581854023988*^9}, {3.7765886860875998`*^9, 3.776588733493191*^9}, {
   3.776589570210289*^9, 3.7765895824655743`*^9}, {3.776590233107551*^9, 
   3.7765902564512787`*^9}, {3.776591571944075*^9, 3.7765915746041203`*^9}, {
   3.776602264582697*^9, 3.776602296926549*^9}, {3.776602375849365*^9, 
   3.776602376041151*^9}, {3.7766026068145113`*^9, 3.776602610806279*^9}, {
   3.776617416423319*^9, 3.776617417851177*^9}, {3.776617514403247*^9, 
   3.776617514699873*^9}, {3.776619517807181*^9, 3.7766195186750193`*^9}, {
   3.776619586920179*^9, 3.776619588403123*^9}, 3.776619682014089*^9, {
   3.776619761488949*^9, 3.776619768486827*^9}, {3.776652008104575*^9, 
   3.776652013165792*^9}, {3.776652046363044*^9, 3.7766520783755493`*^9}, {
   3.776652647062893*^9, 3.7766526565893497`*^9}, {3.776658517847208*^9, 
   3.7766585185255537`*^9}, 3.780125464260351*^9, {3.780126663910887*^9, 
   3.780126673538025*^9}, {3.780126714885847*^9, 3.7801267856496897`*^9}, {
   3.780126856387533*^9, 3.7801268608026342`*^9}, {3.7801270206345778`*^9, 
   3.780127058613825*^9}, {3.780127165077898*^9, 3.780127166404272*^9}, {
   3.780127328892138*^9, 3.7801273385327663`*^9}, {3.780127448268403*^9, 
   3.780127473839093*^9}, {3.780127526829754*^9, 3.780127540047349*^9}, {
   3.780127585790882*^9, 3.780127587351294*^9}, {3.780127628604958*^9, 
   3.780127629612442*^9}, 3.780127886388055*^9, {3.780127930021605*^9, 
   3.780127930244035*^9}, {3.7801279986713753`*^9, 3.7801280020140743`*^9}, {
   3.780297688869789*^9, 3.780297695029997*^9}, {3.78029778526637*^9, 
   3.780297824453166*^9}, 3.781583958313833*^9, {3.7852339025917683`*^9, 
   3.785233902890212*^9}, {3.785234087992731*^9, 3.785234090092032*^9}, {
   3.7855719491046257`*^9, 3.785571961616921*^9}, {3.785572033219342*^9, 
   3.785572045003989*^9}, {3.8018438489532337`*^9, 3.8018438527646313`*^9}, {
   3.8018438927350616`*^9, 3.801844019582242*^9}, {3.801910533808075*^9, 
   3.801910534299789*^9}, {3.8019107172381897`*^9, 3.801910742699505*^9}, {
   3.802424186646809*^9, 3.802424187672854*^9}, {3.8085380846621923`*^9, 
   3.808538110430223*^9}, {3.8085395053414927`*^9, 3.808539563364452*^9}, {
   3.8465822604050283`*^9, 3.84658226190913*^9}},
 FontSize->24,ExpressionUUID->"38a7dde9-ccce-426d-849e-3ad602ff7f79"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"yk", "=", 
   RowBox[{"NDSolveValue", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "''"}], "[", "x", "]"}], "\[Equal]", 
        RowBox[{"yig", "[", "x", "]"}]}], ",", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",",
      "y", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"tf", "+", 
        RowBox[{"10", "*", "dt"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yk2", " ", "=", " ", "yk"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"damped", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"t0", ",", 
      RowBox[{"yk", "[", "t0", "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<damped.csv\>\"", ",", "damped", ",", "\"\<CSV\>\""}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.776581953319024*^9, 3.77658198648687*^9}, {
   3.776582312079364*^9, 3.7765823747276077`*^9}, {3.776582645734304*^9, 
   3.776582645865841*^9}, {3.776582934789962*^9, 3.776582936728952*^9}, 
   3.776582995188039*^9, {3.776583085598281*^9, 3.776583136105446*^9}, {
   3.776583240505677*^9, 3.7765832592846003`*^9}, {3.776588743327682*^9, 
   3.7765887441822357`*^9}, {3.7765897281519337`*^9, 
   3.7765897296297903`*^9}, {3.7765897632709827`*^9, 3.776589795830523*^9}, {
   3.776590269976549*^9, 3.77659028323075*^9}, 3.776591331207336*^9, {
   3.776593813093701*^9, 3.776593813343238*^9}, {3.7766001033568373`*^9, 
   3.776600103714571*^9}, {3.77660255725648*^9, 3.776602557884591*^9}, {
   3.776735478105653*^9, 3.776735478207014*^9}, {3.7767372639237547`*^9, 
   3.776737264055985*^9}, {3.7790889584202147`*^9, 3.779088961532586*^9}, 
   3.780125462413033*^9, 3.7801268908980217`*^9, {3.7801269843172083`*^9, 
   3.7801270042783527`*^9}, 3.780127304631805*^9, 3.780127369834283*^9, 
   3.780127407014407*^9, {3.780128025194737*^9, 3.780128027418181*^9}, {
   3.780193703198078*^9, 3.78019370394844*^9}, {3.780369900441348*^9, 
   3.7803699007122583`*^9}, {3.7804541476916924`*^9, 
   3.7804541478758373`*^9}, {3.7833232257416897`*^9, 3.783323226804438*^9}, {
   3.78333297597712*^9, 3.783332976440979*^9}, 3.7852273446213512`*^9, {
   3.78557200909594*^9, 3.785572010080082*^9}, {3.785638336287578*^9, 
   3.785638337222973*^9}, {3.7858098377908163`*^9, 3.7858098387505827`*^9}, {
   3.78635291731851*^9, 3.786352918350439*^9}, 3.7863530419912786`*^9, {
   3.786354905980095*^9, 3.786354906474574*^9}, {3.789223583534359*^9, 
   3.789223584600979*^9}, 3.7892656862995033`*^9, {3.789286880459016*^9, 
   3.789286881946907*^9}, {3.7916244151415052`*^9, 3.791624418844655*^9}, 
   3.8018435796649437`*^9, 3.8018440543304977`*^9, {3.801905529436866*^9, 
   3.801905529705852*^9}, 3.802232014895458*^9, 3.802232060202093*^9, {
   3.802427117484956*^9, 3.802427143623654*^9}, {3.808300713127431*^9, 
   3.808300714760083*^9}, {3.808300759653274*^9, 3.808300760689989*^9}, {
   3.808480281729414*^9, 3.808480282881629*^9}, {3.8084804445583677`*^9, 
   3.808480473877198*^9}, {3.808481777590625*^9, 3.8084818035146112`*^9}, {
   3.80853800647176*^9, 3.8085380086124783`*^9}, {3.8085407972462387`*^9, 
   3.8085407979051113`*^9}, {3.8085410889806004`*^9, 
   3.8085411030874157`*^9}, {3.808541299435029*^9, 3.808541300198278*^9}, {
   3.80856698386911*^9, 3.808566992356835*^9}, 3.808567045548422*^9, {
   3.808567095847061*^9, 3.808567096263749*^9}, {3.8085685018446703`*^9, 
   3.8085685024218884`*^9}, 3.8085695258797398`*^9, {3.8085697538269577`*^9, 
   3.8085697560350943`*^9}, {3.808574019931941*^9, 3.808574020454187*^9}, {
   3.8443040201185417`*^9, 3.844304024278048*^9}, {3.84510149705891*^9, 
   3.845101497690732*^9}},
 FontSize->24,ExpressionUUID->"b5ec3e67-6ac5-4d8c-a656-2fa218ceeeb8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"yk", "[", "x", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.776591424010969*^9, 3.776591515207591*^9, 3.7765923785010643`*^9, {
   3.776602421366428*^9, 3.776602426694955*^9}, {3.7767370016238956`*^9, 
   3.776737002071076*^9}, {3.7801251270081253`*^9, 3.780125127701457*^9}, {
   3.780125276660059*^9, 3.780125278241947*^9}, 3.780125460024384*^9, 
   3.780126889803164*^9, 3.780127306855526*^9, 3.780127377698779*^9, 
   3.780127411071096*^9, {3.780128020594123*^9, 3.7801280645360117`*^9}, {
   3.780128169950861*^9, 3.78012817634459*^9}, {3.781583974169235*^9, 
   3.7815839788868437`*^9}, {3.783306409386866*^9, 3.7833064687422953`*^9}, {
   3.783306509221182*^9, 3.783306524597514*^9}, {3.7833066119711523`*^9, 
   3.783306625706828*^9}, {3.783306798683611*^9, 3.783306803018528*^9}, {
   3.7833068439942617`*^9, 3.783306863490274*^9}, {3.783306915586286*^9, 
   3.783306918937113*^9}, {3.783323135568563*^9, 3.7833231617958527`*^9}, {
   3.7833232099581614`*^9, 3.783323230021686*^9}, {3.783332978914406*^9, 
   3.783332979393886*^9}, 3.7852205885719557`*^9, {3.7852207320333023`*^9, 
   3.7852207325674477`*^9}, {3.785226633465066*^9, 3.785226633959096*^9}, {
   3.785572013712734*^9, 3.7855720177523413`*^9}, {3.785638313812428*^9, 
   3.7856383408872623`*^9}, {3.7858098473295717`*^9, 3.785809861418171*^9}, {
   3.785809901624704*^9, 3.785809902775848*^9}, {3.7863473874330587`*^9, 
   3.786347389527258*^9}, {3.786347973911903*^9, 3.786347991719376*^9}, {
   3.786352922040543*^9, 3.786352926352046*^9}, {3.786352975496181*^9, 
   3.786352975991027*^9}, {3.786354924286684*^9, 3.786354924758705*^9}, {
   3.789265874405326*^9, 3.789265874860656*^9}, {3.790319600350322*^9, 
   3.790319602142148*^9}, {3.790319714392791*^9, 3.7903197153197803`*^9}, 
   3.801844092933778*^9, {3.801905536346219*^9, 3.80190553650282*^9}, {
   3.802245752075684*^9, 3.802245756210067*^9}, 3.8023396163736277`*^9, {
   3.802520304180422*^9, 3.8025203596449833`*^9}, {3.808474621829108*^9, 
   3.808474625621052*^9}, {3.8084802403398046`*^9, 3.808480259498082*^9}, {
   3.8084817592049627`*^9, 3.808481772415588*^9}, {3.808481823944908*^9, 
   3.808481825388949*^9}, {3.8085403328312683`*^9, 3.808540333730913*^9}},
 FontSize->24,ExpressionUUID->"3ecdd6ed-fa98-4b43-b4f6-5d8631895d85"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwUmXc4le8bwKOIbwNFGWVlpEJGJcWdVLZshbIiMkJZ2XvvvUKFlL0S8iB7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       "]]},
     Annotation[#, "Charting`Private`Tag$5939#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{925., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.780127357431299*^9, 3.78012741193202*^9}, 
   3.780127514046191*^9, 3.780127957254548*^9, {3.780128011751742*^9, 
   3.780128065650155*^9}, {3.780128171591228*^9, 3.7801281767226686`*^9}, 
   3.7801935781845407`*^9, 3.780193739544076*^9, 3.7801946465856953`*^9, 
   3.780199602531352*^9, 3.780199654392954*^9, 3.7802158559555063`*^9, 
   3.780220799896199*^9, 3.7802239509991302`*^9, 3.780224118165039*^9, 
   3.780297843539219*^9, 3.780297892419088*^9, 3.780299392948279*^9, 
   3.780299584500329*^9, 3.7802997233161592`*^9, 3.78030388533103*^9, 
   3.7803039839590693`*^9, 3.780304037836512*^9, 3.7803044628500013`*^9, 
   3.780304503191904*^9, 3.780305047786789*^9, 3.7803051015636673`*^9, 
   3.780305887906003*^9, 3.780306322839665*^9, 3.780308129250049*^9, 
   3.780366162944437*^9, 3.780366256253291*^9, 3.780366432982025*^9, 
   3.780367171177984*^9, 3.7803673159028273`*^9, 3.780367346603704*^9, 
   3.780367454059436*^9, 3.780367887393259*^9, 3.780368106265444*^9, 
   3.780368256225586*^9, 3.780368555490933*^9, 3.780368612460458*^9, 
   3.7803690714112167`*^9, 3.780369121465291*^9, 3.780369200662753*^9, 
   3.780369293772129*^9, 3.780369466387404*^9, 3.780369594190433*^9, 
   3.780369640138186*^9, 3.780369722676684*^9, 3.780369766026081*^9, 
   3.780369838876965*^9, 3.780369936717289*^9, 3.780370146524493*^9, 
   3.7803702967411623`*^9, 3.780370361841152*^9, 3.780370556270446*^9, 
   3.780370719795348*^9, {3.7803707554423447`*^9, 3.7803707739408197`*^9}, 
   3.780371111480548*^9, 3.7803711674198923`*^9, 3.7803712193524942`*^9, 
   3.78037127807028*^9, 3.780371761637151*^9, {3.780371819058393*^9, 
   3.7803718393224916`*^9}, 3.780371933434929*^9, 3.7803720926948566`*^9, 
   3.78037241822541*^9, 3.780372918512896*^9, 3.780372953517125*^9, 
   3.7803729945008574`*^9, 3.7803730256483*^9, 3.780373114329891*^9, 
   3.780373144766224*^9, 3.780373179286334*^9, 3.7803734148095417`*^9, 
   3.78037345064469*^9, 3.780382519035015*^9, 3.7803827079758787`*^9, 
   3.780382798167729*^9, 3.7803833664035587`*^9, 3.7803836917567167`*^9, {
   3.780383866369804*^9, 3.780383894928123*^9}, 3.780383933023291*^9, 
   3.780384073108224*^9, {3.780384257968727*^9, 3.780384282553433*^9}, 
   3.780384524261113*^9, 3.780392600287521*^9, {3.780392658017075*^9, 
   3.780392730245908*^9}, 3.780392780653368*^9, 3.780393462095694*^9, 
   3.780393545192882*^9, 3.780400228939825*^9, 3.7804008014725027`*^9, 
   3.780911206851293*^9, {3.780911259643486*^9, 3.780911281060788*^9}, 
   3.780911566266584*^9, 3.780911613127553*^9, 3.780911764218659*^9, 
   3.7809118153737373`*^9, 3.780911870323498*^9, 3.780912007955868*^9, 
   3.7809121060297127`*^9, 3.780912174213009*^9, {3.78091245769862*^9, 
   3.780912476868505*^9}, 3.780912547391231*^9, 3.78091258122887*^9, 
   3.7809133573460293`*^9, 3.781096083902431*^9, 3.781096249359447*^9, 
   3.781101334798889*^9, 3.781101521857156*^9, 3.781230318764984*^9, 
   3.781230795316877*^9, 3.781231013742103*^9, 3.781231095578761*^9, 
   3.781235481627891*^9, 3.781235515148294*^9, 3.781235643079282*^9, {
   3.781236168879582*^9, 3.781236185889303*^9}, 3.781236223497222*^9, 
   3.7812362834156923`*^9, 3.781506118929076*^9, 3.781507372632824*^9, 
   3.781507429449607*^9, 3.781507519598618*^9, 3.7815075681203527`*^9, 
   3.781507920173695*^9, 3.7815080295691423`*^9, 3.781508184218093*^9, 
   3.781508319703245*^9, 3.7815085201313066`*^9, 3.781509222389059*^9, 
   3.781509354563402*^9, 3.781509541635416*^9, 3.781509586578067*^9, 
   3.781510040446766*^9, 3.781510201726894*^9, 3.78151038277516*^9, 
   3.781510564034329*^9, 3.78151118666809*^9, 3.781511347954365*^9, 
   3.781511433551511*^9, 3.781511548859077*^9, 3.7815823574851007`*^9, 
   3.781582649714322*^9, 3.781582715277935*^9, 3.7815830756648903`*^9, 
   3.781583155620776*^9, 3.781583218688304*^9, 3.781583387963242*^9, 
   3.781583471133025*^9, 3.781583989907856*^9, 3.781584036888382*^9, 
   3.781584255248995*^9, 3.781584349783942*^9, 3.7815844884308977`*^9, 
   3.783306152887868*^9, {3.783306429321842*^9, 3.7833064588885937`*^9}, 
   3.783306500903659*^9, {3.783306593295821*^9, 3.7833066354566517`*^9}, {
   3.7833067867157717`*^9, 3.783306803493288*^9}, {3.783306845902622*^9, 
   3.78330686412306*^9}, 3.7833069516596193`*^9, 3.783307210702096*^9, 
   3.783307324605575*^9, 3.783307377341385*^9, 3.7833074243885317`*^9, 
   3.7833074738596573`*^9, 3.783307514044221*^9, 3.783307562102111*^9, 
   3.783323023704319*^9, 3.7833230705255947`*^9, {3.783323122715457*^9, 
   3.7833231567568417`*^9}, 3.783323196330349*^9, 3.783323263580578*^9, 
   3.783323359447823*^9, 3.783323439355139*^9, 3.7833234908093224`*^9, 
   3.783323564246934*^9, 3.7833236137948847`*^9, 3.783323666773888*^9, 
   3.78332370928347*^9, 3.783323761326545*^9, 3.7833238045133133`*^9, 
   3.7833238469990263`*^9, 3.783323889277054*^9, 3.783323934347549*^9, 
   3.783329900167322*^9, 3.783329954939447*^9, 3.783330007371456*^9, 
   3.7833301016883097`*^9, 3.78333084238948*^9, 3.7833308861764717`*^9, 
   3.783330936714119*^9, 3.7833309838106537`*^9, 3.783332958743243*^9, 
   3.783333016389948*^9, 3.7833330667537823`*^9, 3.783333112959244*^9, 
   3.783333159143537*^9, 3.783333199287458*^9, 3.7833332397435713`*^9, 
   3.783333279950327*^9, 3.783333332495236*^9, 3.783333372120696*^9, 
   3.783333412637127*^9, 3.783335756429937*^9, 3.78334141878019*^9, 
   3.783341498183984*^9, 3.783394695647469*^9, 3.783403249553685*^9, 
   3.783403298754292*^9, 3.783403341997809*^9, 3.783403402520948*^9, 
   3.783666209197114*^9, 3.783666247938808*^9, 3.78522062415233*^9, 
   3.7852207582803783`*^9, 3.785221429160111*^9, 3.785223775145711*^9, 
   3.785226026725361*^9, 3.785226191249861*^9, 3.7852264907137737`*^9, 
   3.785226647171672*^9, 3.785227189136005*^9, 3.785227311519432*^9, 
   3.7852274715945063`*^9, 3.785233915161602*^9, 3.785568556779338*^9, 
   3.7855686612541723`*^9, {3.785568777911337*^9, 3.7855687934361687`*^9}, 
   3.7855712272130136`*^9, 3.785571401814863*^9, 3.785571545148707*^9, 
   3.785571975873993*^9, {3.785572019695808*^9, 3.785572039420101*^9}, 
   3.7855721249854193`*^9, 3.785572684236126*^9, 3.785573798596195*^9, {
   3.7855738377651854`*^9, 3.785573867517229*^9}, 3.785574074379916*^9, 
   3.785638174392744*^9, {3.7856382944333467`*^9, 3.7856383457907553`*^9}, {
   3.785638391525635*^9, 3.785638416635795*^9}, {3.78563846962755*^9, 
   3.785638504371344*^9}, {3.785638546382245*^9, 3.785638618832505*^9}, 
   3.785638870845237*^9, {3.7856397160429573`*^9, 3.785639738017767*^9}, 
   3.7856603492946*^9, 3.78580987178576*^9, 3.785809915441997*^9, 
   3.785811473581922*^9, {3.786347370518252*^9, 3.786347394884551*^9}, {
   3.786347977821459*^9, 3.786348002158657*^9}, {3.7863480620085907`*^9, 
   3.7863480924980593`*^9}, 3.786348325481193*^9, {3.786348367673037*^9, 
   3.78634839507469*^9}, 3.786349718693928*^9, 3.786349789339081*^9, 
   3.786352930848257*^9, 3.786352980641407*^9, {3.7863530486766453`*^9, 
   3.786353067514566*^9}, 3.786354577515093*^9, {3.786354912710491*^9, 
   3.786354928173276*^9}, 3.7892240780311737`*^9, 3.78922530630303*^9, 
   3.7892656898833942`*^9, 3.789265884167411*^9, 3.789266191108963*^9, 
   3.789287654247244*^9, 3.789288603684231*^9, 3.789874685090403*^9, 
   3.789875678254468*^9, 3.790317027510696*^9, 3.790319159528857*^9, 
   3.790319605145348*^9, 3.7903197293285723`*^9, 3.7916244277023153`*^9, 
   3.80139310173847*^9, 3.801468233037225*^9, 3.801468327111011*^9, 
   3.8014684665268784`*^9, 3.8014686342872343`*^9, 3.801469326191011*^9, 
   3.80146991803808*^9, 3.801470083122913*^9, 3.801470124399665*^9, 
   3.801473309699862*^9, 3.80148265897079*^9, 3.8015664573322163`*^9, 
   3.801566952555841*^9, 3.8016284890023537`*^9, 3.8016288370953197`*^9, 
   3.801628874918125*^9, 3.8016295993748703`*^9, {3.801630297158951*^9, 
   3.801630316777066*^9}, 3.801630579582006*^9, 3.801630876506404*^9, 
   3.80163132087908*^9, 3.801631408140819*^9, 3.801635935406892*^9, 
   3.801635972931683*^9, 3.8016365491994047`*^9, 3.8016366054144487`*^9, 
   3.801637034317725*^9, 3.8016384951593323`*^9, 3.801638565292109*^9, 
   3.8016386111466293`*^9, 3.801640588971751*^9, 3.801640722183312*^9, 
   3.801640958142064*^9, 3.801657514934675*^9, 3.80165763638992*^9, 
   3.801658325696742*^9, 3.801666831209854*^9, 3.801666922902463*^9, 
   3.801667392395537*^9, 3.801668491896138*^9, 3.801668760999655*^9, 
   3.801669167205121*^9, 3.8016698502021713`*^9, 3.801718757829805*^9, 
   3.801825630072618*^9, 3.8018260430411053`*^9, 3.801826790839501*^9, 
   3.801826865594863*^9, 3.801843332818159*^9, {3.801844082735634*^9, 
   3.8018440955069313`*^9}, 3.80184455429988*^9, 3.801844776288871*^9, 
   3.8018449763938828`*^9, 3.801845103594388*^9, 3.8019033724271927`*^9, 
   3.801903708747242*^9, 3.80190418130892*^9, 3.8019056622455263`*^9, 
   3.80191044148659*^9, 3.801910584218288*^9, 3.8019121119486227`*^9, 
   3.801912458801383*^9, 3.801912691914003*^9, 3.8019128860126057`*^9, 
   3.801912985963059*^9, 3.801913451976375*^9, 3.801915130804895*^9, 
   3.8019152790453176`*^9, 3.80191667546015*^9, 3.801916883872469*^9, 
   3.802007406372601*^9, 3.802231318199141*^9, 3.802232065754265*^9, 
   3.80223281857628*^9, 3.8022344652180367`*^9, 3.8022370011917057`*^9, 
   3.802245756992673*^9, 3.802245811598715*^9, 3.8022462827873707`*^9, 
   3.802247664728895*^9, 3.802248001560755*^9, 3.8023370000268793`*^9, 
   3.802337883661255*^9, 3.802338344031624*^9, 3.802338907442573*^9, 
   3.8023392132075768`*^9, 3.802339404984576*^9, 3.802339867941415*^9, 
   3.802349719389227*^9, 3.8023503791182632`*^9, 3.802351363123395*^9, 
   3.802352583400481*^9, 3.8023537286082563`*^9, 3.8023557015742607`*^9, 
   3.802415550667138*^9, 3.802420438118758*^9, 3.802420597224555*^9, 
   3.8024211797337713`*^9, 3.802422056717008*^9, 3.802422429040957*^9, 
   3.802424074141612*^9, 3.802424251198689*^9, 3.80242442289491*^9, 
   3.802424884115466*^9, 3.8024256993090076`*^9, 3.8024261420816803`*^9, 
   3.8024261940329723`*^9, 3.80242676936623*^9, 3.802426890488306*^9, 
   3.802427058526359*^9, {3.802427128214191*^9, 3.802427156927072*^9}, 
   3.802517030799116*^9, 3.802517280759943*^9, 3.802517372108807*^9, 
   3.802517490933587*^9, 3.802518218253474*^9, {3.802519434478773*^9, 
   3.802519459729725*^9}, 3.802519510624936*^9, 3.802519553694642*^9, 
   3.802519600148134*^9, 3.802519665998369*^9, 3.802519800053911*^9, 
   3.802519923453211*^9, 3.8025200271232023`*^9, 3.802520124729643*^9, 
   3.802520227240533*^9, {3.802520305052599*^9, 3.80252037716541*^9}, 
   3.8025204258943853`*^9, 3.802520543349*^9, 3.8025206837066174`*^9, 
   3.802520956046712*^9, 3.802521008037064*^9, 3.8025210948469877`*^9, {
   3.80252119314837*^9, 3.80252122314713*^9}, 3.802521304628888*^9, 
   3.80430421911455*^9, 3.804513578718094*^9, 3.804514655869713*^9, 
   3.806568929876666*^9, 3.8065693606370707`*^9, 3.80656940151886*^9, 
   3.8066484457606153`*^9, 3.8066611256158113`*^9, 3.807362449912456*^9, 
   3.807373942117523*^9, {3.807374007083356*^9, 3.80737403253224*^9}, 
   3.808296792995697*^9, 3.808296912310955*^9, 3.808297005249641*^9, 
   3.808298720652886*^9, 3.8082987774796333`*^9, 3.8082990127818003`*^9, {
   3.808299098904037*^9, 3.808299122839877*^9}, 3.808299203861578*^9, 
   3.808299415972023*^9, 3.808299601426386*^9, 3.80829989368361*^9, 
   3.8083001830084476`*^9, 3.808300241722747*^9, 3.808300362277935*^9, 
   3.808300475170947*^9, 3.808300731093876*^9, 3.8083007772572927`*^9, 
   3.8083015243796473`*^9, 3.808301569404681*^9, {3.808301717298319*^9, 
   3.8083017443671827`*^9}, {3.80830189539146*^9, 3.808301923135219*^9}, {
   3.8083021227013187`*^9, 3.8083021424434023`*^9}, 3.808302508369079*^9, 
   3.8083025474004707`*^9, 3.808302712965581*^9, 3.808302767549314*^9, 
   3.8083028857242928`*^9, 3.808302923495742*^9, 3.808303020769969*^9, 
   3.808303052061376*^9, 3.80830310067733*^9, 3.808303219895575*^9, 
   3.808303507960479*^9, 3.8083036830553093`*^9, 3.808303736168824*^9, 
   3.8083040467651577`*^9, 3.808304154108315*^9, 3.808304266987261*^9, {
   3.808305250278223*^9, 3.808305278359709*^9}, 3.808305616953076*^9, 
   3.8083073115262747`*^9, 3.808309935427457*^9, 3.808314409224872*^9, 
   3.808314574686103*^9, 3.8084495117900963`*^9, 3.80844968783671*^9, 
   3.8084499306775417`*^9, 3.808455474334167*^9, 3.808457645210541*^9, 
   3.8084604384191713`*^9, 3.808469255513783*^9, {3.808474596760211*^9, 
   3.808474626568612*^9}, 3.808474816739002*^9, 3.808480319631915*^9, 
   3.8084805164723673`*^9, 3.80848057315618*^9, 3.808481837997568*^9, 
   3.808481959590205*^9, 3.8084822096140013`*^9, 3.808484811763006*^9, 
   3.808497172878985*^9, {3.808537993293345*^9, 3.8085380151702967`*^9}, 
   3.808538098279697*^9, 3.808538137297401*^9, {3.8085395457910147`*^9, 
   3.80853956762845*^9}, 3.808540338426132*^9, 3.808540452903222*^9, 
   3.80854095165796*^9, {3.8085410940232277`*^9, 3.8085411145216*^9}, 
   3.808541327063366*^9, 3.8085671054693613`*^9, 3.808568513496924*^9, 
   3.808569540440455*^9, {3.808569582380563*^9, 3.808569687325696*^9}, 
   3.8085697776329603`*^9, 3.8085740534564867`*^9, {3.808757701077326*^9, 
   3.808757803152858*^9}, {3.808758482427107*^9, 3.808758633983097*^9}, 
   3.808758676698044*^9, 3.8088194930648212`*^9, 3.808820428075817*^9, 
   3.80882109554963*^9, 3.808846123011973*^9, 3.8088861149046383`*^9, {
   3.808990999361362*^9, 3.808991016551141*^9}, 3.844303899394906*^9, 
   3.844303976992288*^9, 3.844304939752389*^9, 3.844304974967348*^9, {
   3.8443059023326063`*^9, 3.844305922346003*^9}, 3.844305978334096*^9, {
   3.844306851977064*^9, 3.844306871955268*^9}, {3.844310126120523*^9, 
   3.844310144215419*^9}, {3.8465813720998917`*^9, 3.846581424449106*^9}, 
   3.846581501757718*^9, 3.8465815361796227`*^9, {3.846581666157805*^9, 
   3.8465817009100657`*^9}, {3.8465817686228933`*^9, 3.846581781283414*^9}, 
   3.846581828865471*^9, 3.846581934325857*^9, 3.846582018275918*^9, {
   3.8465821514091797`*^9, 3.846582180186123*^9}, 3.846582265176334*^9, 
   3.8465823045662117`*^9, 3.846582367414083*^9},
 FontSize->24,ExpressionUUID->"eb1860f2-32d5-4f37-a57c-fd052bdbb687"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     StyleBox[
      RowBox[{"C", 
       StyleBox[
        StyleBox["a",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "lc", 
       StyleBox[
        StyleBox["u",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "la", 
       StyleBox[
        StyleBox["t",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], 
       StyleBox[
        StyleBox[
         StyleBox["e",
          FontFamily->"Source Code Pro",
          FontWeight->"Bold"],
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"]}]], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox["Numerical",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["d",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "erivative"}]]}], " ", "*)"}],
   FontFamily->"Source Code Pro",
   FontWeight->"Bold"], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ykd", "[", "x_", "]"}], ":=", " ", 
    RowBox[{"ND", "[", 
     RowBox[{
      RowBox[{"yk", "[", "r", "]"}], ",", "r", ",", "x", ",", 
      RowBox[{"Scale", "\[Rule]", "dt"}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.776590678665509*^9, 3.776590707130846*^9}, 
   3.776591451968889*^9, 3.776591488140933*^9, {3.776591880645617*^9, 
   3.776591917089058*^9}, {3.776592109452311*^9, 3.7765921358471603`*^9}, {
   3.776592168099957*^9, 3.7765921694170523`*^9}, {3.776592217505624*^9, 
   3.776592233360197*^9}, {3.776592293682795*^9, 3.7765923071621523`*^9}, {
   3.7765923377330637`*^9, 3.776592339788952*^9}, 3.776592595055973*^9, {
   3.776592655288542*^9, 3.7765926635503693`*^9}, {3.7765927220175247`*^9, 
   3.776592752944021*^9}, 3.776593027711937*^9, {3.776593099790422*^9, 
   3.776593130105191*^9}, 3.780125452355077*^9, 3.780192810868984*^9, {
   3.802231977862303*^9, 3.802231986900173*^9}, {3.8083021371011677`*^9, 
   3.808302138320127*^9}, {3.8451015423071547`*^9, 3.845101543632864*^9}},
 FontSize->24,ExpressionUUID->"f9ee7cd5-70e7-456c-9b5e-9a5359727b89"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xnq", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"0", ",", "tf", ",", 
     RowBox[{"dt", "*", "0.01"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.776593154829524*^9, 3.776593165030897*^9}, 
   3.7765937459144783`*^9, 3.7765938013629713`*^9, {3.776593973381551*^9, 
   3.776593987416609*^9}, {3.776600507816163*^9, 3.7766005347514973`*^9}, {
   3.7767372407437363`*^9, 3.7767372608158073`*^9}, {3.7801254448236513`*^9, 
   3.780125450512713*^9}, 3.780192809068877*^9, {3.780193336252203*^9, 
   3.7801933412847843`*^9}, {3.780193714376379*^9, 3.780193715726727*^9}, {
   3.780369913010612*^9, 3.7803699132577868`*^9}, 3.781509304003355*^9, {
   3.781510184548312*^9, 3.781510184978723*^9}, {3.8018443745662003`*^9, 
   3.801844375162558*^9}, {3.8019055433099613`*^9, 3.801905543541046*^9}, {
   3.802232160727398*^9, 3.802232161543544*^9}, 3.8022322162793827`*^9, {
   3.802427033952756*^9, 3.802427035197926*^9}, 3.8024271016059504`*^9, {
   3.808299406313184*^9, 3.808299406796708*^9}, {3.8083000922990513`*^9, 
   3.808300092607461*^9}, {3.808300684159997*^9, 3.8083006905850782`*^9}, {
   3.808301512728352*^9, 3.808301514121476*^9}, 3.808301563321395*^9},
 FontSize->24,ExpressionUUID->"ea6cd35f-7ef6-4016-bcf1-c422ebbced6e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ykdn", " ", "=", " ", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"xnq", ",", 
       RowBox[{"ykd", "[", "xnq", "]"}]}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ykdn", "[", "x", "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.776593122728952*^9, 3.776593127151803*^9}, {
   3.776593691774273*^9, 3.776593706090396*^9}, {3.776593830643197*^9, 
   3.7765938382672977`*^9}, 3.776593990448572*^9, {3.776594103598421*^9, 
   3.776594125967247*^9}, 3.780125443533125*^9, 3.780192807769244*^9, 
   3.7801934309045258`*^9, 3.78022919946005*^9, 3.780297881861765*^9, {
   3.780367072332879*^9, 3.7803670786136*^9}, {3.780367108723477*^9, 
   3.7803671467446413`*^9}, {3.780367188733575*^9, 3.780367234750469*^9}, {
   3.780367277600451*^9, 3.780367322300625*^9}, {3.7803673525124063`*^9, 
   3.780367355364842*^9}, {3.780367397052005*^9, 3.780367436834688*^9}, {
   3.78036784995544*^9, 3.780367871169552*^9}, {3.780367980361652*^9, 
   3.7803680933079643`*^9}, 3.780368266236717*^9, {3.7803685088018007`*^9, 
   3.7803685424545097`*^9}, {3.780368591320045*^9, 3.780368600830242*^9}, 
   3.78036865348525*^9, {3.780369036156701*^9, 3.780369054658798*^9}, {
   3.780369101683421*^9, 3.780369106840062*^9}, {3.780369180548604*^9, 
   3.780369181460136*^9}, {3.780369228110744*^9, 3.780369280824313*^9}, {
   3.7803693362831793`*^9, 3.780369454703348*^9}, {3.780369491687997*^9, 
   3.78036958368174*^9}, {3.7803696219116163`*^9, 3.7803696223663692`*^9}, {
   3.780369690448319*^9, 3.780369695976066*^9}, {3.780369734134843*^9, 
   3.780369755088572*^9}, {3.780370329000808*^9, 3.780370347315216*^9}, 
   3.780370543288587*^9, {3.780370684323064*^9, 3.780370699489294*^9}, {
   3.780370736952578*^9, 3.780370762056665*^9}, {3.780370830035028*^9, 
   3.780370831899043*^9}, {3.7803709614518013`*^9, 3.7803711540223083`*^9}, {
   3.78037120295294*^9, 3.7803712072512903`*^9}, {3.780371258179998*^9, 
   3.7803712655807447`*^9}, {3.7803718042165823`*^9, 3.780371827447753*^9}, 
   3.780372056792972*^9, 3.780372379756301*^9, 3.780373014537224*^9, 
   3.780383355823882*^9, {3.780383618838003*^9, 3.780383672202827*^9}, {
   3.780383710164228*^9, 3.780383711862599*^9}, {3.780383794368969*^9, 
   3.780383810740198*^9}, {3.7803838822850847`*^9, 3.780383882804775*^9}, {
   3.780383918622615*^9, 3.780383919189698*^9}, {3.780383974109034*^9, 
   3.7803839745630407`*^9}, 3.7803840601896772`*^9, {3.7803842114831448`*^9, 
   3.780384240241914*^9}, {3.780384270542287*^9, 3.7803843194346952`*^9}, {
   3.7803926107256393`*^9, 3.7803926402894897`*^9}, {3.780392673767096*^9, 
   3.7803927190856543`*^9}, {3.780392763299535*^9, 3.780392767682727*^9}, {
   3.780393256881679*^9, 3.780393259292058*^9}, 3.780393320439764*^9, {
   3.780393374316625*^9, 3.780393435146796*^9}, {3.780393512841404*^9, 
   3.780393514622998*^9}, {3.7804001779481697`*^9, 3.780400178387168*^9}, {
   3.780400516315936*^9, 3.780400535769209*^9}, {3.780400623963386*^9, 
   3.7804006370591097`*^9}, {3.780400755363186*^9, 3.780400788962266*^9}, {
   3.780911738105393*^9, 3.780911739848959*^9}, {3.7810963486542063`*^9, 
   3.781096359405199*^9}, {3.781101271629747*^9, 3.781101304592967*^9}, {
   3.7811015082339354`*^9, 3.781101509866466*^9}, {3.781230396487712*^9, 
   3.781230405214984*^9}, {3.781230978764317*^9, 3.78123097905954*^9}, {
   3.781231027818675*^9, 3.7812310281373777`*^9}, 3.781231082385549*^9, {
   3.781235457935751*^9, 3.781235470976213*^9}, 3.781235502294742*^9, {
   3.781506710578896*^9, 3.7815067167694693`*^9}, 3.781506875669064*^9, {
   3.781506925124234*^9, 3.7815069820506496`*^9}, {3.781507112917378*^9, 
   3.781507138864195*^9}, {3.781507472350222*^9, 3.7815074970561047`*^9}, 
   3.781507535561862*^9, {3.7815084589433737`*^9, 3.78150847222152*^9}, 
   3.781510180292955*^9, {3.7815111657232027`*^9, 3.781511175176029*^9}, {
   3.781580288693633*^9, 3.781580324186282*^9}, 3.7815822309877996`*^9, {
   3.7815822746459627`*^9, 3.781582295761838*^9}, {3.78158300285739*^9, 
   3.781583003332983*^9}, {3.7815831438739777`*^9, 3.781583144317997*^9}, 
   3.781583918006168*^9, 3.785223662764262*^9, {3.785225982746344*^9, 
   3.7852259890188513`*^9}, {3.785227359768322*^9, 3.785227364503668*^9}, 
   3.7855726355438547`*^9, {3.785572668856284*^9, 3.785572678801317*^9}, 
   3.785574059756404*^9, 3.801844402918983*^9, {3.801844456348414*^9, 
   3.8018444995744543`*^9}, {3.801844591050952*^9, 3.801844620401787*^9}, {
   3.8018446746661787`*^9, 3.8018447478009777`*^9}, {3.801844802275223*^9, 
   3.801844808567458*^9}, {3.801905551630971*^9, 3.801905558659502*^9}, 
   3.801915724970728*^9, {3.8019163974755096`*^9, 3.801916433554904*^9}, 
   3.801995723379526*^9, 3.8019957799138117`*^9, {3.8022316927441807`*^9, 
   3.8022317033325853`*^9}, {3.802231854642241*^9, 3.80223186866337*^9}, 
   3.8022319023687963`*^9, 3.802232097207608*^9, {3.802232194586454*^9, 
   3.8022322002501287`*^9}, {3.802232233539186*^9, 3.802232248952716*^9}, 
   3.802233824883279*^9, {3.802427042649309*^9, 3.802427043582666*^9}, 
   3.802427104774487*^9, 3.8025196454426928`*^9, {3.80251968798123*^9, 
   3.802519737641239*^9}, {3.802519904409789*^9, 3.8025199046396103`*^9}, {
   3.802519988347212*^9, 3.8025199885111027`*^9}, {3.802520281278743*^9, 
   3.802520294884399*^9}, {3.802520812941835*^9, 3.802520845627433*^9}},
 FontSize->24,ExpressionUUID->"37a11c79-0e11-4b53-8834-56d4bb5f3c45"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwUV3c8lu8XRrKzd7Ipe6aSnKeQkh0qaRGppFL5SoqEZGWlQhlJyUhWVu7H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       "]]},
     Annotation[#, "Charting`Private`Tag$5987#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.802231907985753*^9, 3.8022320988685923`*^9, {3.8022321673960533`*^9, 
   3.8022322518348007`*^9}, 3.8022328188757143`*^9, 3.802234465507723*^9, 
   3.8022370016648693`*^9, 3.802245811828454*^9, 3.8022462831751337`*^9, 
   3.802247665032243*^9, 3.802248001714304*^9, 3.802337000462607*^9, 
   3.802337884091832*^9, 3.802338344341483*^9, 3.80233890766371*^9, 
   3.8023392134390583`*^9, 3.8023394052854633`*^9, 3.802339868282998*^9, 
   3.8023497197381773`*^9, 3.802350379300288*^9, 3.802351363532978*^9, 
   3.8023525840628757`*^9, 3.802353729013975*^9, 3.802355701899*^9, 
   3.80241555094099*^9, 3.802420438569199*^9, 3.802420597651482*^9, 
   3.802421179981468*^9, 3.802422056955319*^9, 3.802422429424171*^9, 
   3.8024240745021477`*^9, 3.802424251688632*^9, 3.8024244231562223`*^9, 
   3.802424884534196*^9, 3.8024256996503057`*^9, 3.8024261425788927`*^9, 
   3.802426194433145*^9, 3.802426769703483*^9, 3.802426890871785*^9, 
   3.802427058971023*^9, {3.802427128708007*^9, 3.8024271572673893`*^9}, 
   3.802517033356885*^9, 3.802517283640386*^9, 3.802517372257855*^9, 
   3.802517491161804*^9, 3.802518218445183*^9, {3.802519435215053*^9, 
   3.8025194605430717`*^9}, 3.8025195113714037`*^9, 3.802519554654996*^9, 
   3.802519603019702*^9, {3.802519649019928*^9, 3.80251974124325*^9}, 
   3.802519802789804*^9, 3.8025199236797867`*^9, 3.802519989074149*^9, 
   3.802520027761333*^9, 3.8025201251088142`*^9, 3.80252022748298*^9, {
   3.8025202842858877`*^9, 3.802520296002656*^9}, 3.802520377336636*^9, 
   3.802520426159156*^9, 3.802520543508156*^9, 3.802520684050591*^9, {
   3.802520813729616*^9, 3.802520846658128*^9}, 3.80252095644731*^9, 
   3.80252101042638*^9, 3.802521096348092*^9, 3.802521193434754*^9, 
   3.8025212235727053`*^9, 3.802521305259659*^9, 3.804304219446145*^9, 
   3.804513579078219*^9, 3.8045146564178047`*^9, 3.8065689301448298`*^9, 
   3.806569360840481*^9, 3.806569404555765*^9, 3.80664844593801*^9, 
   3.806661129113632*^9, 3.807362450365123*^9, 3.807373945178687*^9, {
   3.807374009359785*^9, 3.807374035159367*^9}, 3.808296793128015*^9, 
   3.8082969124015627`*^9, 3.808297005419421*^9, 3.808298720785038*^9, 
   3.808298777680395*^9, 3.808299012959292*^9, {3.8082990990945063`*^9, 
   3.808299122976984*^9}, 3.8082992040287237`*^9, 3.808299416100679*^9, 
   3.8082996015516233`*^9, 3.808299893805431*^9, 3.8083001831367683`*^9, 
   3.8083002418014793`*^9, 3.808300362360498*^9, 3.808300475250107*^9, 
   3.808300731254386*^9, 3.8083007774242992`*^9, 3.8083015245235443`*^9, 
   3.8083015700555887`*^9, {3.808301717995816*^9, 3.8083017450477552`*^9}, {
   3.8083018961013937`*^9, 3.80830192384626*^9}, {3.808302123366187*^9, 
   3.808302142765594*^9}, 3.8083025086735363`*^9, 3.8083025477091722`*^9, 
   3.8083027132696123`*^9, 3.808302767853943*^9, 3.8083028860485287`*^9, 
   3.8083029238131*^9, 3.808303021095675*^9, 3.8083030523911533`*^9, 
   3.8083031009983892`*^9, 3.808303222364088*^9, 3.808303510362274*^9, 
   3.808303683372274*^9, 3.80830373646206*^9, 3.808304047055193*^9, 
   3.8083041556091347`*^9, 3.8083042683095217`*^9, {3.8083052516257887`*^9, 
   3.808305279694962*^9}, 3.808305617140408*^9, 3.8083073118505363`*^9, 
   3.808309935779793*^9, 3.808314410571191*^9, 3.808314574874406*^9, 
   3.808449512145994*^9, 3.808449688094239*^9, 3.808449932033251*^9, 
   3.808455474704238*^9, 3.8084576456135817`*^9, 3.808460442132831*^9, 
   3.808469282437737*^9, 3.808474600640168*^9, 3.808474820566473*^9, 
   3.808480323439732*^9, 3.80848052048706*^9, 3.808480573600904*^9, 
   3.808481959755954*^9, 3.808482209971387*^9, 3.8084848136476316`*^9, 
   3.808497176358079*^9, {3.8085379995316*^9, 3.808538028950254*^9}, 
   3.808538106064067*^9, 3.8085381569809732`*^9, {3.808539549636752*^9, 
   3.808539571019512*^9}, 3.8085403412526503`*^9, 3.8085404658995457`*^9, 
   3.808540958734517*^9, {3.808541099197064*^9, 3.808541123667561*^9}, 
   3.8085413340590487`*^9, 3.808567112732162*^9, 3.808568519221715*^9, 
   3.808569546388177*^9, {3.808569588133832*^9, 3.808569697776814*^9}, 
   3.808569788869398*^9, 3.808574059085147*^9, {3.80875770361823*^9, 
   3.808757782905266*^9}, {3.808758488106217*^9, 3.808758638552977*^9}, 
   3.808758681639834*^9, 3.808819498088496*^9, 3.808820433294066*^9, 
   3.8088210997293797`*^9, 3.808846126613798*^9, 3.8088861194486322`*^9, {
   3.808991003815833*^9, 3.8089910212629213`*^9}, 3.844303902778285*^9, 
   3.8443039802545767`*^9, 3.844304943251848*^9, 3.8443049782997427`*^9, {
   3.844305905651607*^9, 3.8443059256497173`*^9}, 3.844305979547565*^9, {
   3.8443068532152243`*^9, 3.844306874283771*^9}, {3.844310128431926*^9, 
   3.844310145318988*^9}, {3.8465813752150707`*^9, 3.8465814280285873`*^9}, 
   3.846581505325714*^9, 3.846581538587763*^9, {3.8465816715602493`*^9, 
   3.846581704456936*^9}, {3.8465817725849543`*^9, 3.846581783288273*^9}, 
   3.846581832281431*^9, 3.846581937079463*^9, 3.8465820222488937`*^9, {
   3.8465821563491917`*^9, 3.846582183092948*^9}, 3.846582268657271*^9, 
   3.846582310013711*^9, 
   3.846582372209717*^9},ExpressionUUID->"964df6b6-e8f3-4959-aacd-\
1e7c170313a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Calculate", " ", 
     StyleBox["the",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["u",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "nknown"}]], " ", 
     StyleBox["laplace",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["i",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "nversion"}]], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox[
         StyleBox["t",
          FontFamily->"Source Code Pro",
          FontWeight->"Bold"],
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "er", 
       StyleBox["m",
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], 
       StyleBox[
        StyleBox["s",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"]}]], " ", 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["i",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "nside"}]], " ", 
     StyleBox["the",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["i",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "ntegrals"}]], " ", 
     StyleBox["in",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["I",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "DE"}]], " ", 
     StyleBox["numerically",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"]}], 
    StyleBox[
     RowBox[{
      StyleBox[" ",
       FontFamily->"Source Code Pro",
       FontWeight->"Bold"], " "}]], "*)"}],
   FontFamily->"Source Code Pro",
   FontWeight->"Bold"], 
  StyleBox["\[IndentingNewLine]",
   FontFamily->"Source Code Pro",
   FontWeight->"Bold"], 
  RowBox[{
   RowBox[{"l", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", 
       FractionBox["s", "\[Nu]"]}], ")"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fun2", "[", "s_", "]"}], "=", 
     RowBox[{"zeta", "[", "s", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t0", "=", 
     RowBox[{"Range", "[", 
      RowBox[{"ti", ",", "tf", ",", "dt"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fun2s", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FT", "[", 
        RowBox[{"fun2", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "ti", ",", "tf", ",", "dt"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fun2s1", " ", "=", " ", 
     RowBox[{"Flatten", "[", "fun2s", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fun2si", " ", "=", " ", 
     RowBox[{"Interpolation", "[", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"t0", ",", "fun2s1"}], "}"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"fun2si", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "ti", ",", "tf"}], "}"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.776593122728952*^9, 3.776593127151803*^9}, {
   3.776593691774273*^9, 3.776593706090396*^9}, {3.776593830643197*^9, 
   3.7765938382672977`*^9}, 3.776593990448572*^9, {3.776594103598421*^9, 
   3.776594125967247*^9}, 3.780125443533125*^9, 3.780192807769244*^9, 
   3.7801934309045258`*^9, 3.78022919946005*^9, 3.780297881861765*^9, {
   3.780367072332879*^9, 3.7803670786136*^9}, {3.780367108723477*^9, 
   3.7803671467446413`*^9}, {3.780367188733575*^9, 3.780367234750469*^9}, {
   3.780367277600451*^9, 3.780367322300625*^9}, {3.7803673525124063`*^9, 
   3.780367355364842*^9}, {3.780367397052005*^9, 3.780367436834688*^9}, {
   3.78036784995544*^9, 3.780367871169552*^9}, {3.780367980361652*^9, 
   3.7803680933079643`*^9}, 3.780368266236717*^9, {3.7803685088018007`*^9, 
   3.7803685424545097`*^9}, {3.780368591320045*^9, 3.780368600830242*^9}, 
   3.78036865348525*^9, {3.780369036156701*^9, 3.780369054658798*^9}, {
   3.780369101683421*^9, 3.780369106840062*^9}, {3.780369180548604*^9, 
   3.780369181460136*^9}, {3.780369228110744*^9, 3.780369280824313*^9}, {
   3.7803693362831793`*^9, 3.780369454703348*^9}, {3.780369491687997*^9, 
   3.78036958368174*^9}, {3.7803696219116163`*^9, 3.7803696223663692`*^9}, {
   3.780369690448319*^9, 3.780369695976066*^9}, {3.780369734134843*^9, 
   3.780369755088572*^9}, {3.780370329000808*^9, 3.780370347315216*^9}, 
   3.780370543288587*^9, {3.780370684323064*^9, 3.780370699489294*^9}, {
   3.780370736952578*^9, 3.780370762056665*^9}, {3.780370830035028*^9, 
   3.780370831899043*^9}, {3.7803709614518013`*^9, 3.7803711540223083`*^9}, {
   3.78037120295294*^9, 3.7803712072512903`*^9}, {3.780371258179998*^9, 
   3.7803712655807447`*^9}, {3.7803718042165823`*^9, 3.780371827447753*^9}, 
   3.780372056792972*^9, 3.780372379756301*^9, 3.780373014537224*^9, 
   3.780383355823882*^9, {3.780383618838003*^9, 3.780383672202827*^9}, {
   3.780383710164228*^9, 3.780383711862599*^9}, {3.780383794368969*^9, 
   3.780383810740198*^9}, {3.7803838822850847`*^9, 3.780383882804775*^9}, {
   3.780383918622615*^9, 3.780383919189698*^9}, {3.780383974109034*^9, 
   3.7803839745630407`*^9}, 3.7803840601896772`*^9, {3.7803842114831448`*^9, 
   3.780384240241914*^9}, {3.780384270542287*^9, 3.7803843194346952`*^9}, {
   3.7803926107256393`*^9, 3.7803926402894897`*^9}, {3.780392673767096*^9, 
   3.7803927190856543`*^9}, {3.780392763299535*^9, 3.780392767682727*^9}, {
   3.780393256881679*^9, 3.780393259292058*^9}, 3.780393320439764*^9, {
   3.780393374316625*^9, 3.780393435146796*^9}, {3.780393512841404*^9, 
   3.780393514622998*^9}, {3.7804001779481697`*^9, 3.780400178387168*^9}, {
   3.780400516315936*^9, 3.780400535769209*^9}, {3.780400623963386*^9, 
   3.7804006370591097`*^9}, {3.780400755363186*^9, 3.780400788962266*^9}, {
   3.780911738105393*^9, 3.780911739848959*^9}, {3.7810963486542063`*^9, 
   3.781096359405199*^9}, {3.781101271629747*^9, 3.781101304592967*^9}, {
   3.7811015082339354`*^9, 3.781101509866466*^9}, {3.781230396487712*^9, 
   3.781230405214984*^9}, {3.781230978764317*^9, 3.78123097905954*^9}, {
   3.781231027818675*^9, 3.7812310281373777`*^9}, 3.781231082385549*^9, {
   3.781235457935751*^9, 3.781235470976213*^9}, 3.781235502294742*^9, {
   3.781506710578896*^9, 3.7815067167694693`*^9}, 3.781506875669064*^9, {
   3.781506925124234*^9, 3.7815069820506496`*^9}, {3.781507112917378*^9, 
   3.781507138864195*^9}, {3.781507472350222*^9, 3.7815074970561047`*^9}, 
   3.781507535561862*^9, {3.7815084589433737`*^9, 3.78150847222152*^9}, 
   3.781510180292955*^9, {3.7815111657232027`*^9, 3.781511175176029*^9}, {
   3.781580288693633*^9, 3.781580324186282*^9}, 3.7815822309877996`*^9, {
   3.7815822746459627`*^9, 3.781582295761838*^9}, {3.78158300285739*^9, 
   3.781583003332983*^9}, {3.7815831438739777`*^9, 3.781583144317997*^9}, 
   3.781583918006168*^9, 3.785223662764262*^9, {3.785225982746344*^9, 
   3.7852259890188513`*^9}, {3.785227359768322*^9, 3.785227364503668*^9}, 
   3.7855726355438547`*^9, {3.785572668856284*^9, 3.785572678801317*^9}, 
   3.785574059756404*^9, 3.801844402918983*^9, {3.801844456348414*^9, 
   3.8018444995744543`*^9}, {3.801844591050952*^9, 3.801844620401787*^9}, {
   3.8018446746661787`*^9, 3.8018447478009777`*^9}, {3.801844802275223*^9, 
   3.801844808567458*^9}, {3.801905551630971*^9, 3.801905558659502*^9}, 
   3.801915724970728*^9, {3.8019163974755096`*^9, 3.801916433554904*^9}, 
   3.801995723379526*^9, 3.8019957799138117`*^9, {3.8022316927441807`*^9, 
   3.8022317033325853`*^9}, {3.802231854642241*^9, 3.80223186866337*^9}, 
   3.8022319023687963`*^9, {3.802232485294241*^9, 3.802232499065937*^9}, {
   3.8022326067581673`*^9, 3.80223262590655*^9}, {3.802232670493599*^9, 
   3.802232675119298*^9}, {3.802232749964323*^9, 3.802232751258053*^9}, 
   3.8022332902282763`*^9, {3.8022336777505293`*^9, 3.8022336815642557`*^9}, {
   3.8022338452643557`*^9, 3.80223388366914*^9}, {3.802233922421089*^9, 
   3.8022339324422817`*^9}, {3.802234119654339*^9, 3.802234136261791*^9}, {
   3.8022342192351847`*^9, 3.8022342399476433`*^9}, {3.802421782414049*^9, 
   3.802421812172448*^9}, {3.8024256794741898`*^9, 3.8024256899720488`*^9}, {
   3.8024267554570436`*^9, 3.8024267638089123`*^9}, {3.8082994354572887`*^9, 
   3.808299451626424*^9}, 3.808299510020628*^9, {3.8083001004524927`*^9, 
   3.808300114642799*^9}, {3.8083003285784903`*^9, 3.808300338963461*^9}, {
   3.845101564747971*^9, 3.845101566430208*^9}, {3.846582353943461*^9, 
   3.846582360463846*^9}},
 FontSize->24,ExpressionUUID->"98796199-16be-423a-9954-5519d883d4b3"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"23.04`", "\[VeryThinSpace]", "+", 
   RowBox[{"9.569999999999999`", " ", "s"}]}]]], "Output",
 CellChangeTimes->{{3.802232643596682*^9, 3.802232691140079*^9}, 
   3.802232767693533*^9, 3.8022328330429296`*^9, 3.8022333062588463`*^9, 
   3.802233696443775*^9, 3.802233899436776*^9, 3.8022339491882133`*^9, 
   3.802234160473938*^9, {3.8022342343669167`*^9, 3.8022342552387857`*^9}, 
   3.802234479475081*^9, 3.802237015861031*^9, 3.802245826065406*^9, 
   3.802246297166976*^9, 3.802247679714402*^9, 3.802248015708926*^9, 
   3.8023370150476093`*^9, 3.8023378988726587`*^9, 3.802338358572933*^9, 
   3.802338921906769*^9, 3.802339228119369*^9, 3.8023394197077913`*^9, 
   3.802339882715439*^9, 3.8023497338715277`*^9, 3.8023503935012608`*^9, 
   3.802351378031362*^9, 3.802352598920693*^9, 3.802353732789383*^9, 
   3.8023557043396673`*^9, 3.8024155533404007`*^9, 3.802420441076252*^9, 
   3.802420600387898*^9, 3.8024211821275578`*^9, {3.802421794928141*^9, 
   3.802421814928237*^9}, 3.802422058017293*^9, 3.802422430378606*^9, 
   3.802424075306231*^9, 3.8024242524779577`*^9, 3.802424424568618*^9, 
   3.8024248857390833`*^9, 3.80242570067973*^9, 3.8024261436788883`*^9, 
   3.802426195630187*^9, 3.802426770680118*^9, 3.802426891892161*^9, 
   3.8024270599659157`*^9, {3.802427129828896*^9, 3.802427158278701*^9}, 
   3.80251703576586*^9, 3.802517286161367*^9, 3.802517374540339*^9, 
   3.8025174935026207`*^9, 3.802518220701981*^9, {3.8025194377099237`*^9, 
   3.8025194629343157`*^9}, 3.802519513637499*^9, 3.802519557065647*^9, 
   3.8025196053720093`*^9, 3.802519671262569*^9, 3.80251980503913*^9, 
   3.802519931131575*^9, 3.802520035141364*^9, 3.802520132561287*^9, 
   3.802520234830428*^9, 3.802520378477642*^9, 3.802520427253797*^9, 
   3.8025205446178827`*^9, 3.802520685053834*^9, 3.8025209576954737`*^9, 
   3.802521011492972*^9, 3.802521097002913*^9, 3.8025211939921227`*^9, 
   3.8025212241949797`*^9, 3.802521305926476*^9, 3.804304221533527*^9, 
   3.804513581365437*^9, 3.804514672745675*^9, 3.806568931509226*^9, 
   3.806569362144397*^9, 3.806569405108683*^9, 3.8066484464606743`*^9, 
   3.8066611298222313`*^9, 3.807373945875759*^9, 3.8073740356328497`*^9, 
   3.8082967936219997`*^9, 3.80829691291571*^9, 3.8082970059076033`*^9, 
   3.808298721308271*^9, 3.8082987781674747`*^9, 3.8082990134723997`*^9, {
   3.808299099589158*^9, 3.8082991234613256`*^9}, 3.808299204168008*^9, 
   3.808299416266326*^9, 3.8082996127695713`*^9, 3.808299893906156*^9, 
   3.8083001832403097`*^9, 3.808300242510598*^9, 3.808300362421283*^9, 
   3.808300475615018*^9, 3.8083007316259317`*^9, 3.808300777782454*^9, 
   3.8083015248786697`*^9, 3.808301570459134*^9, {3.808301718408599*^9, 
   3.8083017454511433`*^9}, {3.8083018965407457`*^9, 3.808301924250761*^9}, {
   3.808302123783511*^9, 3.808302143175288*^9}, 3.808302509084428*^9, 
   3.808302548133789*^9, 3.8083027136933203`*^9, 3.8083027682531548`*^9, 
   3.808302886452505*^9, 3.808302924252708*^9, 3.808303021517549*^9, 
   3.808303052808536*^9, 3.808303101406974*^9, 3.808303228848279*^9, 
   3.808303516748633*^9, 3.808303683773099*^9, 3.808303736863411*^9, 
   3.808304047470956*^9, 3.80830415863236*^9, 3.808304271350779*^9, {
   3.808305254634549*^9, 3.808305282732489*^9}, 3.8083056176005907`*^9, 
   3.8083073126608953`*^9, 3.808309936428933*^9, 3.808314415082741*^9, 
   3.8083145752173033`*^9, 3.808449512514308*^9, 3.8084496884665003`*^9, 
   3.808449936468637*^9, 3.808455475342146*^9, 3.808457646329718*^9, 
   3.8084604557589397`*^9, 3.80846939559334*^9, 3.808474609400098*^9, 
   3.808474838100383*^9, 3.808480340362645*^9, 3.80848053386801*^9, 
   3.808480574425699*^9, 3.8084819600560093`*^9, 3.80848221070173*^9, 
   3.808484819736595*^9, 3.80849719073088*^9, 3.808539550848811*^9, 
   3.808540507931958*^9, 3.808541358212182*^9, 3.8085671359293423`*^9, 
   3.8085685399057837`*^9, {3.808569566436784*^9, 3.808569623159808*^9}, 
   3.8085696536481323`*^9, 3.808569827009219*^9, 3.808574079929852*^9, {
   3.808757726847274*^9, 3.808757745864752*^9}, {3.808758549375648*^9, 
   3.808758585192185*^9}, 3.808758621537011*^9, 3.808758695506205*^9, 
   3.8088195003255997`*^9, 3.808820446345936*^9, 3.8088211027150383`*^9, 
   3.808846137490884*^9, 3.8088861334247932`*^9, {3.80899100731983*^9, 
   3.808991035741935*^9}, 3.8443039032758636`*^9, 3.844303987862609*^9, 
   3.844304953887332*^9, 3.844304988600074*^9, {3.844305910630312*^9, 
   3.8443059382323647`*^9}, 3.8443059856827593`*^9, {3.844306860101233*^9, 
   3.844306886021147*^9}, {3.8443101365047503`*^9, 3.844310152198558*^9}, 
   3.846581672443973*^9, 3.846581774757372*^9, 3.8465821569621067`*^9, 
   3.846582318769109*^9, 
   3.84658237230064*^9},ExpressionUUID->"55301f2e-cc1a-4f36-834a-\
e588a81f8745"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwUV3c81t8XVyRFGSGhJKOSikjCdURGpWhQCcXXShIpeych2Tt7ZWUn6/l8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       "]]},
     Annotation[#, "Charting`Private`Tag$9033#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.802232643596682*^9, 3.802232691140079*^9}, 
   3.802232767693533*^9, 3.8022328330429296`*^9, 3.8022333062588463`*^9, 
   3.802233696443775*^9, 3.802233899436776*^9, 3.8022339491882133`*^9, 
   3.802234160473938*^9, {3.8022342343669167`*^9, 3.8022342552387857`*^9}, 
   3.802234479475081*^9, 3.802237015861031*^9, 3.802245826065406*^9, 
   3.802246297166976*^9, 3.802247679714402*^9, 3.802248015708926*^9, 
   3.8023370150476093`*^9, 3.8023378988726587`*^9, 3.802338358572933*^9, 
   3.802338921906769*^9, 3.802339228119369*^9, 3.8023394197077913`*^9, 
   3.802339882715439*^9, 3.8023497338715277`*^9, 3.8023503935012608`*^9, 
   3.802351378031362*^9, 3.802352598920693*^9, 3.802353732789383*^9, 
   3.8023557043396673`*^9, 3.8024155533404007`*^9, 3.802420441076252*^9, 
   3.802420600387898*^9, 3.8024211821275578`*^9, {3.802421794928141*^9, 
   3.802421814928237*^9}, 3.802422058017293*^9, 3.802422430378606*^9, 
   3.802424075306231*^9, 3.8024242524779577`*^9, 3.802424424568618*^9, 
   3.8024248857390833`*^9, 3.80242570067973*^9, 3.8024261436788883`*^9, 
   3.802426195630187*^9, 3.802426770680118*^9, 3.802426891892161*^9, 
   3.8024270599659157`*^9, {3.802427129828896*^9, 3.802427158278701*^9}, 
   3.80251703576586*^9, 3.802517286161367*^9, 3.802517374540339*^9, 
   3.8025174935026207`*^9, 3.802518220701981*^9, {3.8025194377099237`*^9, 
   3.8025194629343157`*^9}, 3.802519513637499*^9, 3.802519557065647*^9, 
   3.8025196053720093`*^9, 3.802519671262569*^9, 3.80251980503913*^9, 
   3.802519931131575*^9, 3.802520035141364*^9, 3.802520132561287*^9, 
   3.802520234830428*^9, 3.802520378477642*^9, 3.802520427253797*^9, 
   3.8025205446178827`*^9, 3.802520685053834*^9, 3.8025209576954737`*^9, 
   3.802521011492972*^9, 3.802521097002913*^9, 3.8025211939921227`*^9, 
   3.8025212241949797`*^9, 3.802521305926476*^9, 3.804304221533527*^9, 
   3.804513581365437*^9, 3.804514672745675*^9, 3.806568931509226*^9, 
   3.806569362144397*^9, 3.806569405108683*^9, 3.8066484464606743`*^9, 
   3.8066611298222313`*^9, 3.807373945875759*^9, 3.8073740356328497`*^9, 
   3.8082967936219997`*^9, 3.80829691291571*^9, 3.8082970059076033`*^9, 
   3.808298721308271*^9, 3.8082987781674747`*^9, 3.8082990134723997`*^9, {
   3.808299099589158*^9, 3.8082991234613256`*^9}, 3.808299204168008*^9, 
   3.808299416266326*^9, 3.8082996127695713`*^9, 3.808299893906156*^9, 
   3.8083001832403097`*^9, 3.808300242510598*^9, 3.808300362421283*^9, 
   3.808300475615018*^9, 3.8083007316259317`*^9, 3.808300777782454*^9, 
   3.8083015248786697`*^9, 3.808301570459134*^9, {3.808301718408599*^9, 
   3.8083017454511433`*^9}, {3.8083018965407457`*^9, 3.808301924250761*^9}, {
   3.808302123783511*^9, 3.808302143175288*^9}, 3.808302509084428*^9, 
   3.808302548133789*^9, 3.8083027136933203`*^9, 3.8083027682531548`*^9, 
   3.808302886452505*^9, 3.808302924252708*^9, 3.808303021517549*^9, 
   3.808303052808536*^9, 3.808303101406974*^9, 3.808303228848279*^9, 
   3.808303516748633*^9, 3.808303683773099*^9, 3.808303736863411*^9, 
   3.808304047470956*^9, 3.80830415863236*^9, 3.808304271350779*^9, {
   3.808305254634549*^9, 3.808305282732489*^9}, 3.8083056176005907`*^9, 
   3.8083073126608953`*^9, 3.808309936428933*^9, 3.808314415082741*^9, 
   3.8083145752173033`*^9, 3.808449512514308*^9, 3.8084496884665003`*^9, 
   3.808449936468637*^9, 3.808455475342146*^9, 3.808457646329718*^9, 
   3.8084604557589397`*^9, 3.80846939559334*^9, 3.808474609400098*^9, 
   3.808474838100383*^9, 3.808480340362645*^9, 3.80848053386801*^9, 
   3.808480574425699*^9, 3.8084819600560093`*^9, 3.80848221070173*^9, 
   3.808484819736595*^9, 3.80849719073088*^9, 3.808539550848811*^9, 
   3.808540507931958*^9, 3.808541358212182*^9, 3.8085671359293423`*^9, 
   3.8085685399057837`*^9, {3.808569566436784*^9, 3.808569623159808*^9}, 
   3.8085696536481323`*^9, 3.808569827009219*^9, 3.808574079929852*^9, {
   3.808757726847274*^9, 3.808757745864752*^9}, {3.808758549375648*^9, 
   3.808758585192185*^9}, 3.808758621537011*^9, 3.808758695506205*^9, 
   3.8088195003255997`*^9, 3.808820446345936*^9, 3.8088211027150383`*^9, 
   3.808846137490884*^9, 3.8088861334247932`*^9, {3.80899100731983*^9, 
   3.808991035741935*^9}, 3.8443039032758636`*^9, 3.844303987862609*^9, 
   3.844304953887332*^9, 3.844304988600074*^9, {3.844305910630312*^9, 
   3.8443059382323647`*^9}, 3.8443059856827593`*^9, {3.844306860101233*^9, 
   3.844306886021147*^9}, {3.8443101365047503`*^9, 3.844310152198558*^9}, 
   3.846581672443973*^9, 3.846581774757372*^9, 3.8465821569621067`*^9, 
   3.846582318769109*^9, 
   3.846582385757997*^9},ExpressionUUID->"cc149d34-9370-4e8a-ba05-\
81afbbef9de2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"Iteratively", " ", 
     StyleBox[
      RowBox[{
       StyleBox["s",
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "olving"}]], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], "the", " ", 
     StyleBox["complete",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["I",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "DE"}]], " ", 
     StyleBox["with",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["i",
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "ntegral"}]], " ", 
     StyleBox["terms",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], "numerically", 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"de", 
       StyleBox[
        StyleBox[
         StyleBox["f",
          FontFamily->"Source Code Pro",
          FontWeight->"Bold"],
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"],
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "ined"}]], " ", 
     StyleBox["by",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{
       StyleBox["i",
        FontFamily->"Source Code Pro",
        FontWeight->"Bold"], "1"}],
      FontFamily->"Source Code Pro",
      FontWeight->"Bold"], " ", 
     RowBox[{
      StyleBox[
       RowBox[{
        StyleBox[
         StyleBox["b",
          FontFamily->"Source Code Pro",
          FontWeight->"Bold"],
         FontFamily->"Source Code Pro",
         FontWeight->"Bold"], "elow"}]], "."}]}], " ", "*)"}],
   FontFamily->"Source Code Pro",
   FontWeight->"Bold"], "\[IndentingNewLine]", 
  RowBox[{"Do", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", "i1", "]"}], ";", " ", 
     RowBox[{
      RowBox[{"i1", "[", 
       RowBox[{"x_", "?", "NumberQ"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"i1", "[", "x", "]"}], "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"fun2si", "[", 
           RowBox[{"x", "-", "\[Tau]"}], "]"}], "*", 
          RowBox[{"ykdn", "[", "\[Tau]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Tau]", ",", "0", ",", "x"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<LocalAdaptive\>\"", ",", 
            RowBox[{"Method", "\[Rule]", "\"\<LobattoKronrodRule\>\""}]}], 
           "}"}]}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"yk1", "=", 
      RowBox[{"NDSolveValue", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "''"}], "[", "x", "]"}], "\[Equal]", 
           RowBox[{
            RowBox[{"yig", "[", "x", "]"}], "-", 
            RowBox[{"coeff2", "*", 
             RowBox[{"i1", "[", "x", "]"}]}]}]}], ",", 
          RowBox[{
           RowBox[{"y", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], 
        ",", "y", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"xq", "=", 
      RowBox[{"Range", "[", 
       RowBox[{"ti", ",", "tf", ",", "dt"}], "]"}]}], ";", 
     RowBox[{"error1", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"yk1", "[", "xq", "]"}], "-", 
        RowBox[{"yk", "[", "xq", "]"}]}], ")"}]}], ";", 
     RowBox[{"error1", " ", "=", " ", 
      RowBox[{"Max", "[", 
       RowBox[{"Abs", "[", "error1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"yk", "=", "yk1"}], ";", 
     RowBox[{
      RowBox[{"ykd", "[", "x_", "]"}], ":=", " ", 
      RowBox[{"ND", "[", 
       RowBox[{
        RowBox[{"yk", "[", "r", "]"}], ",", "r", ",", "x", ",", 
        RowBox[{"Scale", "\[Rule]", "dt"}]}], "]"}]}], ";", 
     RowBox[{"xnq", "=", 
      RowBox[{"Range", "[", 
       RowBox[{"ti", ",", "tf", ",", "dt"}], "]"}]}], ";", 
     RowBox[{"ykdn1", " ", "=", " ", 
      RowBox[{"Interpolation", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xnq", ",", 
          RowBox[{"ykd", "[", "xnq", "]"}]}], "}"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"Print", "[", "error1", "]"}], ";", " ", 
     RowBox[{"ykdn", "=", "ykdn1"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.776572714030456*^9, 3.776572729087159*^9}, 
   3.776573371818927*^9, 3.7765793616507587`*^9, {3.776579471136483*^9, 
   3.7765794743494663`*^9}, {3.7765839076821327`*^9, 3.776583908854864*^9}, 
   3.776585471828773*^9, {3.776586622771377*^9, 3.7765866240814743`*^9}, {
   3.776586674120646*^9, 3.776586718704813*^9}, {3.7765868962863903`*^9, 
   3.776586930729768*^9}, {3.776586982139798*^9, 3.776586983673285*^9}, {
   3.776587061946931*^9, 3.7765870758577223`*^9}, {3.776587451396212*^9, 
   3.776587459488009*^9}, {3.776587499602735*^9, 3.7765875410092287`*^9}, {
   3.776587584512538*^9, 3.776587598760654*^9}, {3.776587658905593*^9, 
   3.776587824112761*^9}, {3.7765879296561337`*^9, 3.7765879386529903`*^9}, {
   3.7765880418277197`*^9, 3.776588084744632*^9}, {3.776588125585017*^9, 
   3.776588155866333*^9}, {3.77658820442456*^9, 3.7765882172053013`*^9}, {
   3.776588329059042*^9, 3.77658832987204*^9}, {3.776588485652211*^9, 
   3.776588499685814*^9}, {3.776588766707869*^9, 3.7765888311626167`*^9}, 
   3.77658901103715*^9, {3.776589588501346*^9, 3.776589590612505*^9}, {
   3.776589807104556*^9, 3.776589823748921*^9}, {3.776590476207201*^9, 
   3.776590476330933*^9}, {3.776590538270381*^9, 3.776590538611618*^9}, 
   3.776590710980253*^9, {3.776590764425694*^9, 3.776590895725128*^9}, {
   3.776591038241859*^9, 3.776591114426166*^9}, {3.776591162951941*^9, 
   3.776591163391556*^9}, {3.776594244015916*^9, 3.776594302127125*^9}, {
   3.7765955195712767`*^9, 3.776595528979961*^9}, 3.7765955972668962`*^9, {
   3.7765956600941772`*^9, 3.776595686291316*^9}, {3.776595936761319*^9, 
   3.776595953789631*^9}, {3.776596025451055*^9, 3.776596025516447*^9}, {
   3.776600119831949*^9, 3.7766001203665648`*^9}, {3.776600373690968*^9, 
   3.776600382506366*^9}, {3.7766005606266537`*^9, 3.776600561865045*^9}, 
   3.7766008130674667`*^9, 3.7766012013553743`*^9, {3.776601285551936*^9, 
   3.776601294659783*^9}, {3.776602568070261*^9, 3.776602568325857*^9}, {
   3.776603307196166*^9, 3.776603387534506*^9}, {3.7766148854075747`*^9, 
   3.7766148865807962`*^9}, {3.7766157321176147`*^9, 3.776615733225482*^9}, {
   3.776615770346539*^9, 3.776615784696336*^9}, {3.776615840431489*^9, 
   3.776615843562904*^9}, {3.7766160563877897`*^9, 3.776616099611329*^9}, {
   3.7766161298433228`*^9, 3.776616141788322*^9}, {3.776616255038561*^9, 
   3.776616257055522*^9}, {3.776616453037088*^9, 3.776616491453817*^9}, {
   3.776616522928492*^9, 3.776616541088667*^9}, {3.776616599541933*^9, 
   3.776616642140517*^9}, 3.776616674083177*^9, {3.7766167973919697`*^9, 
   3.776616801231208*^9}, {3.776616875772003*^9, 3.776616887754311*^9}, {
   3.7766169226211567`*^9, 3.776616945062043*^9}, {3.7766173522697363`*^9, 
   3.776617352884391*^9}, {3.77661760221702*^9, 3.776617603640265*^9}, {
   3.776618131860654*^9, 3.776618168173945*^9}, {3.7766182554155827`*^9, 
   3.776618256562752*^9}, {3.776618315090172*^9, 3.77661832143268*^9}, {
   3.776618731460436*^9, 3.7766187327329082`*^9}, {3.776619134209449*^9, 
   3.7766191543395844`*^9}, 3.776619248733963*^9, {3.776619297217732*^9, 
   3.776619302247449*^9}, 3.776619460122719*^9, 3.776619629803061*^9, {
   3.7766521214648438`*^9, 3.7766521683533373`*^9}, 3.7766545948416643`*^9, {
   3.776659501929658*^9, 3.7766595040515537`*^9}, {3.776685845465314*^9, 
   3.776685869810663*^9}, {3.776686022834285*^9, 3.776686034573366*^9}, 
   3.776686158917901*^9, {3.77672706761383*^9, 3.776727069515586*^9}, {
   3.7767354677629128`*^9, 3.776735472592342*^9}, {3.7767372225614853`*^9, 
   3.776737225214917*^9}, {3.776737257915083*^9, 3.776737274683633*^9}, 
   3.780125436745557*^9, {3.780132550191929*^9, 3.780132552766471*^9}, 
   3.780192801946547*^9, {3.780193276974527*^9, 3.7801932777010803`*^9}, {
   3.780193363119347*^9, 3.780193403319104*^9}, {3.780193479904133*^9, 
   3.780193559394215*^9}, {3.780194603304215*^9, 3.780194631888193*^9}, {
   3.7802158369365807`*^9, 3.780215838294133*^9}, {3.78022078814126*^9, 
   3.7802207885064983`*^9}, {3.780223632808434*^9, 3.780223639142951*^9}, {
   3.780224106628476*^9, 3.780224107508127*^9}, {3.780299559707692*^9, 
   3.7802995673453293`*^9}, {3.780304439100478*^9, 3.780304487879683*^9}, {
   3.780305830078107*^9, 3.780305831035633*^9}, {3.780306306381873*^9, 
   3.78030630960986*^9}, {3.7803661381229773`*^9, 3.780366149193035*^9}, {
   3.780366241296483*^9, 3.78036624529595*^9}, {3.780366421043262*^9, 
   3.780366421336926*^9}, {3.780368164328278*^9, 3.780368179976012*^9}, {
   3.780369807987365*^9, 3.780369817815071*^9}, {3.780369979778742*^9, 
   3.7803699803085423`*^9}, {3.780370067468252*^9, 3.7803700680252132`*^9}, {
   3.780370278286562*^9, 3.780370285307929*^9}, {3.780370319479739*^9, 
   3.780370326217536*^9}, {3.7803717420104322`*^9, 3.780371750173918*^9}, 
   3.780371799544957*^9, {3.780372897047933*^9, 3.7803728986322613`*^9}, {
   3.780372933641467*^9, 3.780372936454376*^9}, {3.7803729743838053`*^9, 
   3.780372981261429*^9}, {3.7803731031721582`*^9, 3.7803731592046623`*^9}, {
   3.780373384143421*^9, 3.780373384969391*^9}, {3.7803734309391317`*^9, 
   3.780373431927785*^9}, {3.7803825077396927`*^9, 3.7803825295908337`*^9}, {
   3.780382691861964*^9, 3.780382696637354*^9}, {3.78038277490961*^9, 
   3.780382779537395*^9}, {3.780383853823563*^9, 3.780383854010654*^9}, {
   3.780384492733017*^9, 3.780384495069026*^9}, 3.780392588243601*^9, {
   3.780393160782999*^9, 3.780393180056696*^9}, 3.781096162496128*^9, 
   3.78110126763443*^9, {3.781101911767815*^9, 3.7811019166968737`*^9}, {
   3.781230052642538*^9, 3.781230092308023*^9}, {3.781230153797421*^9, 
   3.7812301716408567`*^9}, {3.781230238536653*^9, 3.781230301641491*^9}, 
   3.781230385446601*^9, 3.781506079089177*^9, {3.781506851002996*^9, 
   3.7815068692879343`*^9}, {3.781507415482482*^9, 3.7815074162791367`*^9}, {
   3.781507543747457*^9, 3.7815075470751677`*^9}, {3.78150789627279*^9, 
   3.781507896483657*^9}, {3.781507983877083*^9, 3.781508018676145*^9}, {
   3.7815081621866713`*^9, 3.781508162968058*^9}, {3.781508280546134*^9, 
   3.781508299184814*^9}, {3.7815085032731113`*^9, 3.7815085059725027`*^9}, {
   3.781509210985569*^9, 3.781509211542472*^9}, {3.781509339786788*^9, 
   3.7815093441603727`*^9}, {3.7815094249953337`*^9, 
   3.7815094649917297`*^9}, {3.781510329667756*^9, 3.781510365642922*^9}, {
   3.78151053477175*^9, 3.7815105525717173`*^9}, {3.781511336105782*^9, 
   3.781511336287084*^9}, {3.781511420364891*^9, 3.781511421114176*^9}, {
   3.7815115058712997`*^9, 3.781511537465028*^9}, {3.7815117314852343`*^9, 
   3.7815117319057827`*^9}, {3.7815823303266287`*^9, 3.78158234605659*^9}, {
   3.781582488248258*^9, 3.781582492446661*^9}, {3.78158269829742*^9, 
   3.781582701509891*^9}, {3.781583206328793*^9, 3.7815832080947523`*^9}, {
   3.781583373776084*^9, 3.7815833758360863`*^9}, {3.7815834594180317`*^9, 
   3.781583460758746*^9}, {3.781583593019183*^9, 3.7815835933511963`*^9}, 
   3.781583942198202*^9, {3.781584473004408*^9, 3.7815844738808403`*^9}, {
   3.785227370202277*^9, 3.7852273818586683`*^9}, {3.7858114692482853`*^9, 
   3.785811470013296*^9}, {3.786354861262373*^9, 3.7863548615094643`*^9}, {
   3.7892658193985023`*^9, 3.789265820150023*^9}, {3.789265901992653*^9, 
   3.7892659096977453`*^9}, {3.7916275853162947`*^9, 3.791627587187652*^9}, 
   3.801843649701099*^9, {3.8018448680016813`*^9, 3.801844923165823*^9}, {
   3.801845003066092*^9, 3.801845013473132*^9}, {3.801900210527089*^9, 
   3.801900216542062*^9}, {3.8019006324413223`*^9, 3.801900651259692*^9}, 
   3.801900723723699*^9, {3.801900854949271*^9, 3.8019008557202806`*^9}, {
   3.801901113057036*^9, 3.801901143730616*^9}, {3.8019012111251583`*^9, 
   3.801901253016223*^9}, {3.801902603514793*^9, 3.8019026190677223`*^9}, {
   3.801902942792171*^9, 3.801902952769867*^9}, {3.801903131164312*^9, 
   3.8019031503102827`*^9}, {3.801903300261133*^9, 3.8019033236436462`*^9}, {
   3.801903464736532*^9, 3.801903468940406*^9}, 3.801903514652644*^9, {
   3.8019035607604847`*^9, 3.801903581878991*^9}, {3.80190364682231*^9, 
   3.801903665752328*^9}, 3.801903941631328*^9, {3.8019041544893723`*^9, 
   3.8019041556479073`*^9}, {3.801904347837051*^9, 3.801904348358797*^9}, {
   3.8019055816414833`*^9, 3.801905617174386*^9}, {3.8019103730877123`*^9, 
   3.801910377747657*^9}, 3.8019120387256947`*^9, {3.801912409232791*^9, 
   3.80191241182341*^9}, {3.801912509326482*^9, 3.801912509944971*^9}, {
   3.8019126179324913`*^9, 3.801912622677248*^9}, {3.8019127813280563`*^9, 
   3.801912786619961*^9}, {3.801912934141761*^9, 3.8019129373816233`*^9}, {
   3.801913296412768*^9, 3.80191331169659*^9}, {3.801913403475481*^9, 
   3.8019134084375267`*^9}, {3.801913767247344*^9, 3.8019138003812037`*^9}, 
   3.801913873946498*^9, {3.801914772769712*^9, 3.801914775742725*^9}, {
   3.8019148663829412`*^9, 3.801914868459468*^9}, {3.801915053904022*^9, 
   3.801915083734934*^9}, {3.801915196995612*^9, 3.801915212391019*^9}, {
   3.801916509632717*^9, 3.801916510856879*^9}, 3.8019165635693073`*^9, {
   3.8019167675771027`*^9, 3.801916768014937*^9}, {3.801917193656955*^9, 
   3.801917194715036*^9}, {3.802246152459828*^9, 3.802246158721559*^9}, {
   3.80224729332345*^9, 3.8022472946976643`*^9}, {3.802247910954933*^9, 
   3.802247911786771*^9}, {3.8022646103951406`*^9, 3.8022646156538343`*^9}, {
   3.8023369313808117`*^9, 3.802336954875252*^9}, {3.802338267489215*^9, 
   3.802338280975061*^9}, {3.802338735747382*^9, 3.802338736384733*^9}, {
   3.8023390507493973`*^9, 3.802339056667562*^9}, {3.8023393409906397`*^9, 
   3.802339356270825*^9}, {3.802339685460832*^9, 3.802339709071982*^9}, {
   3.802339805369114*^9, 3.802339810720929*^9}, {3.802349596957737*^9, 
   3.80234965692697*^9}, {3.802350276440588*^9, 3.802350292128315*^9}, 
   3.802351176911462*^9, {3.802351286092095*^9, 3.802351299673684*^9}, {
   3.802420370885086*^9, 3.802420385035493*^9}, {3.802420564602952*^9, 
   3.802420571750024*^9}, {3.802421751787121*^9, 3.802421754150275*^9}, {
   3.802422421324329*^9, 3.8024224218914957`*^9}, {3.802423641959738*^9, 
   3.802423652458733*^9}, {3.802425633845299*^9, 3.802425637383203*^9}, {
   3.802426077086424*^9, 3.8024260793800383`*^9}, {3.802426127724918*^9, 
   3.802426136070711*^9}, {3.802426187400193*^9, 3.8024261886148157`*^9}, {
   3.80251932504108*^9, 3.802519325648842*^9}, {3.802519775452462*^9, 
   3.802519785063957*^9}, {3.802520521381453*^9, 3.80252052857452*^9}, {
   3.8066489055878897`*^9, 3.806648906487522*^9}, {3.8066611071196613`*^9, 
   3.806661107763103*^9}, {3.8082990940957823`*^9, 3.808299132389061*^9}, {
   3.808299459994651*^9, 3.808299471531102*^9}, {3.808300121607452*^9, 
   3.808300130502606*^9}, {3.8083003460222*^9, 3.808300350767302*^9}, {
   3.8083025023209*^9, 3.808302503439143*^9}, {3.808302542696743*^9, 
   3.808302542774332*^9}, {3.808302573945753*^9, 3.8083025743351383`*^9}, {
   3.808302700015854*^9, 3.808302708412745*^9}, {3.808302741892022*^9, 
   3.808302761714429*^9}, {3.808302833047227*^9, 3.808302874183292*^9}, {
   3.808302918668806*^9, 3.808302919091127*^9}, {3.808303086855476*^9, 
   3.808303097293775*^9}, {3.808303486824028*^9, 3.808303492202024*^9}, 
   3.808303727320883*^9, {3.8083038725379457`*^9, 3.808303889378264*^9}, {
   3.8083040399738617`*^9, 3.808304041739913*^9}, {3.808304102193531*^9, 
   3.808304103894693*^9}, 3.808304259103302*^9, {3.808305023802822*^9, 
   3.8083050404740667`*^9}, {3.808305201963426*^9, 3.808305203229854*^9}, 
   3.8083052686394997`*^9, {3.808305541205905*^9, 3.808305541299127*^9}, {
   3.8084496785748243`*^9, 3.8084496820410023`*^9}, {3.8084554055050488`*^9, 
   3.8084554078862743`*^9}, {3.808457636166032*^9, 3.8084576376553087`*^9}, {
   3.808573979573041*^9, 3.8085739800490007`*^9}, {3.845101580452566*^9, 
   3.8451016325259743`*^9}},
 FontSize->24,ExpressionUUID->"bad72af6-3695-4850-b7f8-1df234a4bb32"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction","dmval",
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \\\"3.001`\\\", \\\"}\\\"}]\\) \
lies outside the range of data in the interpolating function. Extrapolation \
will be used.\"",2,147,2,23990039134772666690,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.844307609470686*^9, 3.8443103980959*^9, 
  3.846582325428858*^9, 
  3.846600217596442*^9},ExpressionUUID->"9ec800c7-0b43-474c-947e-\
d0da378450e8"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction","dmval",
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \\\"3.0005`\\\", \\\"}\\\"}]\\) \
lies outside the range of data in the interpolating function. Extrapolation \
will be used.\"",2,147,3,23990039134772666690,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.844307609470686*^9, 3.8443103980959*^9, 
  3.846582325428858*^9, 
  3.8466002179200087`*^9},ExpressionUUID->"5b531890-ab73-47cc-9311-\
54bf34d0d3b0"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction","dmval",
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \\\"3.00025`\\\", \
\\\"}\\\"}]\\) lies outside the range of data in the interpolating function. \
Extrapolation will be used.\"",2,147,4,23990039134772666690,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.844307609470686*^9, 3.8443103980959*^9, 
  3.846582325428858*^9, 
  3.8466002182500257`*^9},ExpressionUUID->"e21409c0-b1f7-46fe-85ff-\
09eef6b2da68"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\
\", \\\"::\\\", \\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,147,5,23990039134772666690,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.844307609470686*^9, 3.8443103980959*^9, 
  3.846582325428858*^9, 
  3.846600218566031*^9},ExpressionUUID->"1c19c761-02c2-4a43-8ba0-\
de88f9550abe"],

Cell[CellGroupData[{

Cell[BoxData["0.04983156985664494`"], "Print",
 CellChangeTimes->{
  3.846600218599634*^9},ExpressionUUID->"73796a2a-a907-4a32-a3ae-\
8a97e358ac58"],

Cell[BoxData["0.0037385276586310717`"], "Print",
 CellChangeTimes->{
  3.846606403992128*^9},ExpressionUUID->"185319bc-c094-4dd8-8d47-\
702398c0ce67"],

Cell[BoxData["0.0003249188554727972`"], "Print",
 CellChangeTimes->{
  3.8466125210118103`*^9},ExpressionUUID->"9ad14b74-d999-4664-b78b-\
0dbc0d635c2f"],

Cell[BoxData["0.000030380984487071716`"], "Print",
 CellChangeTimes->{
  3.8466185771099253`*^9},ExpressionUUID->"2733ea58-7fab-49c6-944b-\
680e959657ed"],

Cell[BoxData["2.9647329363126015`*^-6"], "Print",
 CellChangeTimes->{
  3.846625018377956*^9},ExpressionUUID->"5033e53a-892f-47b1-bf5d-\
d688af5d50c3"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "Plot", " ", "the", " ", "solution", " ", "for", " ", "complete", " ", 
   "IDE", " ", "and", " ", "damped", " ", "equation"}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.776653339696301*^9, 3.7766533564243603`*^9}, {
   3.776653657057764*^9, 3.776653684739113*^9}, 3.776654108157179*^9, 
   3.776654367804389*^9, 3.776753553206805*^9, {3.780036173474922*^9, 
   3.780036217843395*^9}, {3.807362636267694*^9, 3.8073626706546097`*^9}, 
   3.807362747196208*^9, {3.807362785745983*^9, 3.807362794988716*^9}, 
   3.844305014212377*^9, {3.845101640763932*^9, 3.845101651410894*^9}},
 FontSize->24,ExpressionUUID->"166dc07b-b6aa-4e17-8863-40492d1a9ab4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"yk1", "[", "x", "]"}], ",", 
     RowBox[{"yk2", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "ti", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7766200084032907`*^9, 3.776620026805131*^9}, {
   3.776653691916519*^9, 3.7766536950270643`*^9}, {3.776657262732847*^9, 
   3.7766573292776213`*^9}, {3.776657495241941*^9, 3.776657496791514*^9}, {
   3.776657641011825*^9, 3.776657659347218*^9}, {3.776657690770877*^9, 
   3.776657697898012*^9}, {3.776658330720533*^9, 3.776658335103739*^9}, 
   3.7766590013337*^9, {3.776659122317183*^9, 3.776659133151988*^9}, {
   3.7766592680230513`*^9, 3.776659273011572*^9}, {3.7766593500973673`*^9, 
   3.776659350638476*^9}, {3.776685935412487*^9, 3.776685950539795*^9}, {
   3.7766859893698893`*^9, 3.776685995939207*^9}, {3.77668618105545*^9, 
   3.776686182661953*^9}, {3.7766862684825478`*^9, 3.776686278797451*^9}, {
   3.776688135632538*^9, 3.776688136692477*^9}, {3.77668845575292*^9, 
   3.776688457402904*^9}, {3.77668850808622*^9, 3.776688508565721*^9}, {
   3.776688718663039*^9, 3.776688719229224*^9}, {3.7766888859010363`*^9, 
   3.776688889674358*^9}, {3.776689251246942*^9, 3.7766892701444883`*^9}, {
   3.776690001002173*^9, 3.776690002083753*^9}, {3.776690945965683*^9, 
   3.77669096644357*^9}, 3.776691164319457*^9, {3.776735413656007*^9, 
   3.776735449802271*^9}, {3.7767361064175453`*^9, 3.7767361069736977`*^9}, {
   3.776736897804843*^9, 3.7767369018352222`*^9}, {3.776737060801663*^9, 
   3.776737083955181*^9}, {3.776737150452305*^9, 3.776737162256947*^9}, {
   3.776737474983313*^9, 3.776737475772325*^9}, {3.7767376000967407`*^9, 
   3.7767376675336123`*^9}, {3.776737731794458*^9, 3.776737749536374*^9}, {
   3.776737807308342*^9, 3.7767378110515738`*^9}, {3.776737844530657*^9, 
   3.776737849941333*^9}, {3.776753363437983*^9, 3.776753381014817*^9}, {
   3.7767535617675123`*^9, 3.776753562646435*^9}, {3.77675427118932*^9, 
   3.776754323625863*^9}, 3.780125431583395*^9, {3.7801928147604847`*^9, 
   3.780192871246661*^9}, {3.78019356540163*^9, 3.780193566105935*^9}, {
   3.7801944592352543`*^9, 3.780194490566122*^9}, {3.7801945632172327`*^9, 
   3.78019457097577*^9}, {3.780196674995578*^9, 3.7801966805078793`*^9}, {
   3.7801986073043222`*^9, 3.78019861008779*^9}, {3.780198655878903*^9, 
   3.780198657605904*^9}, {3.7801988658033123`*^9, 3.780198871301313*^9}, {
   3.780199041235962*^9, 3.78019910391358*^9}, {3.780199137134346*^9, 
   3.7801991399851837`*^9}, {3.780199210457855*^9, 3.7801992122562532`*^9}, {
   3.7801992537270947`*^9, 3.7801992601425962`*^9}, {3.780199290635948*^9, 
   3.780199291474855*^9}, 3.780210132875122*^9, {3.7802156244811296`*^9, 
   3.780215624872155*^9}, {3.7802206716846867`*^9, 3.780220679662731*^9}, {
   3.7802207227802153`*^9, 3.780220728868638*^9}, {3.7802207711597567`*^9, 
   3.7802207824659157`*^9}, {3.780223814950004*^9, 3.780223815275881*^9}, {
   3.780223875446025*^9, 3.780223932366963*^9}, {3.780228405945299*^9, 
   3.780228412612208*^9}, {3.780297525103039*^9, 3.7802975358243017`*^9}, 
   3.780911804649913*^9, {3.7809118577142267`*^9, 3.780911859656579*^9}, {
   3.780911994763685*^9, 3.780911997786818*^9}, {3.780912534893833*^9, 
   3.78091253753743*^9}, {3.780912568482201*^9, 3.780912571321747*^9}, {
   3.7810961809741917`*^9, 3.781096184428196*^9}, {3.781508048306479*^9, 
   3.781508048832267*^9}, {3.781582425062972*^9, 3.7815824267458487`*^9}, {
   3.783306377397835*^9, 3.7833063813387938`*^9}, {3.7852237470068827`*^9, 
   3.785223747622266*^9}, {3.7852260010689096`*^9, 3.7852260137263927`*^9}, {
   3.7858099085226316`*^9, 3.785809909184389*^9}, {3.789265845993621*^9, 
   3.789265846464711*^9}, {3.789266185630471*^9, 3.7892661861263933`*^9}, {
   3.789267004941339*^9, 3.789267005748386*^9}, {3.789285908523967*^9, 
   3.789285909042859*^9}, {3.789288559311709*^9, 3.7892885691760178`*^9}, {
   3.789874643585998*^9, 3.789874644809231*^9}, {3.789874875493367*^9, 
   3.789874878179296*^9}, 3.801905606545328*^9, {3.8022484199851294`*^9, 
   3.80224843552866*^9}, {3.802338237783153*^9, 3.8023382469855547`*^9}, {
   3.8023401277685957`*^9, 3.8023401416144648`*^9}, 3.8023511597722816`*^9, 
   3.802352889447893*^9, {3.8024222854187183`*^9, 3.802422286116044*^9}, {
   3.802423659183197*^9, 3.802423686258862*^9}, {3.802425090538939*^9, 
   3.802425102945018*^9}, {3.80242683452229*^9, 3.802426872367647*^9}, {
   3.802517466574801*^9, 3.802517469417857*^9}, {3.802520459631323*^9, 
   3.8025205117715263`*^9}, {3.806648364038864*^9, 3.8066483741177607`*^9}, {
   3.8073626235454483`*^9, 3.80736262621388*^9}, 3.8082994934467907`*^9, {
   3.808300137939397*^9, 3.808300138252314*^9}, {3.808300357702273*^9, 
   3.8083003582068872`*^9}, 3.808309630177731*^9, {3.808463282525093*^9, 
   3.808463288583972*^9}, {3.808474879339128*^9, 3.808474879744341*^9}, {
   3.808495458114478*^9, 3.80849549030411*^9}, {3.808495571669595*^9, 
   3.808495572032339*^9}, {3.844304002502775*^9, 3.844304005117593*^9}, {
   3.844306632154873*^9, 3.844306674680613*^9}},
 FontSize->24,ExpressionUUID->"3ab47d70-f2b6-4812-be72-ee98fd16eca1"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwUV3c81e8XVxSlKaVhk51SyMpRyla0Kb4RMko2Ze+9M7O5srL3eoSsyLy2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          "]]}, 
        Annotation[#, "Charting`Private`Tag$5102047#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwUWHc81d8bR75oaGhI2dmjlJGVR5S9k0QUsjJD9koySvYWRTbZLimO7D2u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          "]]}, 
        Annotation[#, "Charting`Private`Tag$5102047#2"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       RowBox[{"yk1", "(", "x", ")"}], 
       RowBox[{"yk2", "(", "x", ")"}]}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7801928485112743`*^9, 3.7801928664143047`*^9}, {
   3.780194449633891*^9, 3.780194490940569*^9}, {3.780194564347355*^9, 
   3.7801945721134357`*^9}, 3.780196515596294*^9, {3.780196675328286*^9, 
   3.780196680845796*^9}, 3.780198612083293*^9, 3.7801986586607437`*^9, 
   3.7801988169766073`*^9, {3.780198866756373*^9, 3.7801988715825653`*^9}, {
   3.780199043258644*^9, 3.780199096227047*^9}, 3.780199143024284*^9, {
   3.780199200209785*^9, 3.7801992128137836`*^9}, 3.7801992604506693`*^9, 
   3.78019929238557*^9, 3.780200661730834*^9, 3.780210136300831*^9, 
   3.780215547265918*^9, 3.780215627146162*^9, 3.780216814671612*^9, {
   3.780220672642099*^9, 3.7802206814614973`*^9}, {3.7802207243550158`*^9, 
   3.780220783106415*^9}, 3.780221239048378*^9, 3.780223816115759*^9, {
   3.780223891723412*^9, 3.780223933117268*^9}, 3.7802251272969217`*^9, {
   3.780228406833309*^9, 3.780228413344488*^9}, {3.78029752663535*^9, 
   3.780297536770926*^9}, 3.780298891863682*^9, {3.780299041933877*^9, 
   3.780299050393448*^9}, 3.7802993933549557`*^9, 3.780299584756942*^9, 
   3.780299723697434*^9, 3.7803038858049173`*^9, 3.7803044233462133`*^9, 
   3.780305048370623*^9, 3.780305817962172*^9, 3.7803068382984047`*^9, 
   3.7803662124957*^9, 3.7803663052580976`*^9, 3.7803665116736507`*^9, 
   3.7803682568525457`*^9, 3.780368556134083*^9, 3.7803686131573*^9, 
   3.7803690719842176`*^9, 3.780369121912486*^9, 3.780369201195188*^9, 
   3.780369294271924*^9, 3.780369466886633*^9, 3.7803695961349897`*^9, 
   3.780369641989875*^9, 3.780369724387*^9, 3.780369767917714*^9, 
   3.780369840867934*^9, 3.780369938506537*^9, 3.780370148385741*^9, 
   3.780370721761763*^9, {3.780370757436556*^9, 3.780370775867588*^9}, 
   3.780371113562669*^9, 3.78037116948457*^9, 3.780371221342292*^9, 
   3.7803712800866613`*^9, 3.780371762402026*^9, {3.7803718211649*^9, 
   3.780371841384659*^9}, 3.78037193536557*^9, 3.7803720946637383`*^9, 
   3.780372420304922*^9, 3.780372919850172*^9, 3.780372954768105*^9, 
   3.780372995401873*^9, 3.7803730264570723`*^9, 3.78037311620042*^9, 
   3.780381974243966*^9, 3.780382750519256*^9, 3.7803926006062403`*^9, {
   3.780392658425653*^9, 3.780392730720245*^9}, 3.78039278253915*^9, 
   3.780911764518222*^9, 3.780911815627818*^9, 3.780911870805936*^9, 
   3.78091200838272*^9, 3.7809121063264914`*^9, 3.780912174545828*^9, {
   3.780912458175448*^9, 3.780912477194689*^9}, 3.780912547856349*^9, 
   3.780912581616549*^9, 3.7809133576316357`*^9, 3.781096084525873*^9, 
   3.7811015223629837`*^9, 3.7812307959252357`*^9, 3.781231014232367*^9, 
   3.781235515602874*^9, 3.7812356434484797`*^9, {3.7812361693027773`*^9, 
   3.781236186351125*^9}, 3.781236223910204*^9, 3.7812362838193083`*^9, 
   3.781507454715383*^9, 3.781507527621318*^9, {3.781508038837826*^9, 
   3.781508067937583*^9}, 3.781508193383031*^9, 3.781508343266118*^9, 
   3.781508553204094*^9, 3.7815092558166656`*^9, 3.781509381949301*^9, 
   3.781509568523082*^9, 3.781509613401861*^9, 3.78151006827355*^9, 
   3.781510280177813*^9, 3.781510495981254*^9, 3.781510601361199*^9, 
   3.781511222553096*^9, 3.7815114048907537`*^9, 3.781511485737691*^9, 
   3.7815116314393053`*^9, {3.781582403757247*^9, 3.7815824289732313`*^9}, 
   3.781582671431696*^9, 3.781582752373931*^9, 3.7815831097420273`*^9, 
   3.781583190151353*^9, 3.7815832717547827`*^9, 3.78158344918461*^9, 
   3.78158353320732*^9, 3.781584152209385*^9, 3.7815843109887657`*^9, 
   3.7815844142481947`*^9, 3.781584590756323*^9, {3.783306369805179*^9, 
   3.783306382222797*^9}, 3.783341683905395*^9, 3.783394876412051*^9, 
   3.785220882744789*^9, 3.7852238869817753`*^9, 3.785226125556306*^9, 
   3.785226293635865*^9, 3.785226585809161*^9, 3.7852267491953907`*^9, 
   3.785227289505031*^9, 3.78522753073048*^9, 3.785233972643847*^9, 
   3.785572727044733*^9, 3.7855741119456453`*^9, 3.78563822805678*^9, {
   3.785810027453677*^9, 3.785810046812574*^9}, 3.785811695348378*^9, 
   3.78634805121665*^9, 3.786353146667482*^9, 3.78922411960646*^9, 
   3.7892253475442266`*^9, 3.789265810919835*^9, 3.789266932200467*^9, 
   3.789267007037333*^9, 3.789285913190935*^9, 3.7892881820249987`*^9, {
   3.789288561164163*^9, 3.789288569524768*^9}, 3.7892887485061693`*^9, 
   3.789874830538179*^9, 3.789874880974679*^9, 3.789875793390518*^9, 
   3.7904157458674183`*^9, 3.801628650479494*^9, 3.801630803549645*^9, 
   3.801635908892668*^9, 3.80163848394044*^9, 3.801657724141335*^9, 
   3.801667509389604*^9, 3.801668607946437*^9, 3.801668841411145*^9, 
   3.801669994515071*^9, 3.80184478456699*^9, 3.801844984649967*^9, 
   3.801845119368927*^9, 3.801903386516468*^9, 3.801903618191249*^9, 
   3.8019036813169403`*^9, 3.801903722806419*^9, 3.801904195716764*^9, 
   3.801904359246035*^9, 3.801905690637473*^9, 3.801910393110223*^9, 
   3.801910470188467*^9, 3.801910612480901*^9, 3.8019121402201147`*^9, 
   3.801912486835476*^9, 3.8019129127262774`*^9, 3.8019130128878098`*^9, 
   3.801913478115951*^9, 3.801914081756105*^9, 3.801915158006587*^9, 
   3.8019153060179*^9, 3.8019167027638197`*^9, 3.801917175772993*^9, 
   3.8020074330690928`*^9, 3.802231345040848*^9, 3.802232846205175*^9, 
   3.802234980098151*^9, 3.802237518377026*^9, 3.802246674187895*^9, {
   3.802247878913486*^9, 3.80224789836073*^9}, 3.80224837545081*^9, {
   3.802248421071192*^9, 3.802248438220377*^9}, 3.8023373488552017`*^9, 
   3.802338201095131*^9, {3.802338239192733*^9, 3.802338248241106*^9}, 
   3.802338659663727*^9, 3.802338845834415*^9, 3.8023389987072697`*^9, 
   3.802339030601302*^9, 3.802339261253392*^9, {3.8023394322962723`*^9, 
   3.802339439614562*^9}, 3.8023400614571857`*^9, {3.802340128465436*^9, 
   3.802340142570322*^9}, 3.8023501843423*^9, 3.802350789262207*^9, {
   3.802351155532867*^9, 3.802351160092937*^9}, 3.8023516533809834`*^9, {
   3.802352877020056*^9, 3.8023528909172163`*^9}, 3.8023539801711197`*^9, 
   3.802355913048579*^9, 3.80241576224362*^9, 3.802420941200322*^9, 
   3.802422254925309*^9, 3.80242228783432*^9, 3.802422827324136*^9, {
   3.802423660179606*^9, 3.802423687767651*^9}, 3.802424079218933*^9, 
   3.8024242564634943`*^9, 3.8024244334149437`*^9, {3.802425082315688*^9, 
   3.802425103802835*^9}, 3.802425724100005*^9, 3.802426166275655*^9, 
   3.802426222423991*^9, 3.802426797739451*^9, {3.802426850064331*^9, 
   3.8024268733643227`*^9}, 3.802426969491659*^9, 3.802427235492216*^9, 
   3.8025174511538343`*^9, 3.802518062313161*^9, 3.8025192855523653`*^9, 
   3.802520383669867*^9, {3.802520451421081*^9, 3.802520502781797*^9}, 
   3.802520631919909*^9, 3.80252119681101*^9, 3.802521268982638*^9, 
   3.8025213108156967`*^9, 3.804304352182382*^9, 3.80451425609864*^9, 
   3.8045193711759872`*^9, 3.8065947726174517`*^9, {3.806648365693619*^9, 
   3.8066483765580063`*^9}, 3.80664846452032*^9, 3.8066878410899343`*^9, 
   3.807390511786476*^9, 3.8082969166878157`*^9, 3.8082987271424417`*^9, {
   3.80829910217554*^9, 3.808299126044796*^9}, 3.8082999019056807`*^9, 
   3.808300186795699*^9, 3.808300265958053*^9, 3.808300362672415*^9, 
   3.808300483081352*^9, 3.8083007383714657`*^9, 3.808300784614972*^9, 
   3.8083015397458*^9, 3.8083015839214153`*^9, {3.808301731920401*^9, 
   3.808301758980712*^9}, {3.808301910125988*^9, 3.808301937845167*^9}, {
   3.808302137370492*^9, 3.8083021615199842`*^9}, 3.8083025272262287`*^9, 
   3.8083025662442293`*^9, 3.808302735775104*^9, 3.8083029062990217`*^9, 
   3.8083029455349493`*^9, 3.808303073393819*^9, 3.8083031194855757`*^9, 
   3.80830375492134*^9, 3.8083041149718027`*^9, 3.8083052547556467`*^9, 
   3.8083054974571867`*^9, 3.8083060643499107`*^9, 3.808314976995504*^9, 
   3.8084498596144457`*^9, 3.808455076177472*^9, 3.80845603627181*^9, 
   3.808457703513481*^9, 3.808462057074108*^9, {3.808463275614498*^9, 
   3.8084632909081697`*^9}, 3.8084821286866817`*^9, 3.808483821956213*^9, 
   3.808490944037809*^9, 3.8084954241615057`*^9, {3.808495460951583*^9, 
   3.808495490749156*^9}, 3.8084955800236397`*^9, {3.808497065507366*^9, 
   3.80849706766474*^9}, 3.8085226772661037`*^9, 3.808542558772027*^9, 
   3.8085679738067713`*^9, 3.8085694008821774`*^9, 3.8085731762064342`*^9, 
   3.808575736845615*^9, 3.8087684571140347`*^9, 3.808883371503108*^9, 
   3.808921433485422*^9, 3.8443065907837667`*^9, {3.8443066347821712`*^9, 
   3.844306675705954*^9}, 3.844308413672818*^9, 3.844310725103681*^9, 
   3.8466250187269363`*^9},
 FontSize->24,ExpressionUUID->"ca59937d-5de3-4a6b-97e2-79754ead71a9"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.785226787139529*^9, 3.785226810190297*^9}, 
   3.785233883281899*^9, 3.8451016620365334`*^9},
 FontSize->24,ExpressionUUID->"6861bd18-e4b7-42b8-bd0b-4ccfe963e84b"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Export", " ", "final", " ", "solution"}], "*)"}]], "Input",
 CellChangeTimes->{{3.785226787139529*^9, 3.785226810190297*^9}, 
   3.785233883281899*^9, {3.8451011120865097`*^9, 3.845101118229927*^9}},
 FontSize->24,ExpressionUUID->"0ed0e200-8e62-4395-a6b5-ec8e8d4b5276"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"ti", ",", "tf", ",", "dt"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789184989985158*^9, 3.789185004379122*^9}, 
   3.7891857013674183`*^9, {3.789265923275124*^9, 3.789265924443034*^9}, {
   3.804552937546492*^9, 3.804552938499029*^9}, {3.806569330604031*^9, 
   3.806569331214767*^9}, 3.807362609972495*^9, {3.808496817139155*^9, 
   3.80849683446106*^9}},
 FontSize->24,ExpressionUUID->"eb043169-a279-4e07-b51c-e7ecebec4393"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sagar", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"t1", ",", 
      RowBox[{"yk1", "[", "t1", "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789183993195862*^9, 3.789184024743524*^9}, {
   3.789184084871964*^9, 3.789184131702663*^9}, {3.78918434967727*^9, 
   3.789184351428762*^9}, {3.7891848739719152`*^9, 3.789184895284977*^9}, {
   3.789184929138817*^9, 3.7891849320013*^9}, {3.7891849646945047`*^9, 
   3.78918497691127*^9}, {3.789185008036672*^9, 3.789185015836728*^9}, 
   3.789185073220476*^9, {3.789225185854389*^9, 3.789225189244359*^9}, {
   3.78922536877835*^9, 3.789225369555874*^9}, 3.807362605698984*^9, 
   3.808496815281712*^9, {3.845101663676361*^9, 3.8451016638841877`*^9}},
 FontSize->24,ExpressionUUID->"4e3f6060-42f9-4ca8-82bd-d9cf1b067315"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<ivp.csv\>\"", ",", "sagar", ",", "\"\<CSV\>\""}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.780126125722629*^9, 3.780126125734283*^9}, {
   3.789183301299758*^9, 3.789183352802553*^9}, {3.789183437102425*^9, 
   3.789183438638607*^9}, {3.7891837608752527`*^9, 3.789183768636819*^9}, {
   3.789183802089467*^9, 3.789183834541173*^9}, {3.789184354501356*^9, 
   3.789184359078451*^9}, {3.789185761766573*^9, 3.789185762454818*^9}, {
   3.789185850466317*^9, 3.789185852834505*^9}, 3.789186111021099*^9, {
   3.789225194742285*^9, 3.7892252005089483`*^9}, 3.789265667920895*^9, {
   3.789286903709934*^9, 3.789286904365943*^9}, {3.789874634328652*^9, 
   3.789874635033049*^9}, {3.789875651684856*^9, 3.78987565301191*^9}, {
   3.7903191512016582`*^9, 3.790319151873104*^9}, {3.804552946490066*^9, 
   3.804552948124426*^9}, {3.8065693234839773`*^9, 3.806569324892434*^9}, 
   3.807362601406445*^9, 3.808496813359466*^9, {3.808567023431975*^9, 
   3.8085670334456587`*^9}, {3.808567087701956*^9, 3.8085670881111727`*^9}, {
   3.80856849297552*^9, 3.8085684937199183`*^9}, 3.808569515972033*^9, {
   3.808569764855154*^9, 3.8085697667193823`*^9}, {3.808574030608734*^9, 
   3.808574031085065*^9}, {3.845101666557222*^9, 3.8451016694919853`*^9}},
 FontSize->24,ExpressionUUID->"5161df72-a8b7-426b-a11f-e5bc0293de1a"]
},
WindowSize->{1855, 1056},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.2 for Linux x86 (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 2404, 52, 446, "Input",ExpressionUUID->"5171e089-ec43-4ae7-9b36-e4b41d7c73d7"],
Cell[2965, 74, 14369, 241, 574, "Input",ExpressionUUID->"85473b9d-1979-4501-b199-72ad7b47a03a"],
Cell[CellGroupData[{
Cell[17359, 319, 8812, 173, 612, "Input",ExpressionUUID->"09889190-8b07-487b-a6a7-bd08a73c21f0"],
Cell[26174, 494, 369, 6, 35, "Output",ExpressionUUID->"f9511c38-3b98-47a8-8bc7-1684ce0af0c7"],
Cell[26546, 502, 369, 6, 35, "Output",ExpressionUUID->"283af3ce-52a4-44f3-8322-09d90b3701f6"],
Cell[26918, 510, 625, 16, 53, "Output",ExpressionUUID->"9027c40c-85b9-4812-9520-e1b873b2b1c7"],
Cell[27546, 528, 436, 9, 35, "Output",ExpressionUUID->"3fe623b6-8b9d-414b-8434-164dd963ee59"],
Cell[27985, 539, 434, 9, 35, "Output",ExpressionUUID->"e0006969-c3ce-4870-a137-037ceac0b4ef"],
Cell[28422, 550, 367, 6, 35, "Output",ExpressionUUID->"68fff86c-0634-4a30-936b-929b4c5c95e9"]
}, Open  ]],
Cell[28804, 559, 1961, 37, 87, "Input",ExpressionUUID->"badeca00-a417-4ff1-a9cb-5e95feb1f0bc"],
Cell[30768, 598, 3048, 45, 86, "Input",ExpressionUUID->"86989e75-c811-432b-a218-2e4062dc7931"],
Cell[33819, 645, 1485, 51, 45, "Input",ExpressionUUID->"b0c8d03c-8236-4abd-a9fb-bbcc535ffbb1"],
Cell[35307, 698, 319, 5, 45, "Input",ExpressionUUID->"599a8d82-97b7-4b2d-bd29-163f3c89f313"],
Cell[35629, 705, 3044, 52, 95, "Input",ExpressionUUID->"38a7dde9-ccce-426d-849e-3ad602ff7f79"],
Cell[38676, 759, 3977, 75, 166, "Input",ExpressionUUID->"b5ec3e67-6ac5-4d8c-a656-2fa218ceeeb8"],
Cell[CellGroupData[{
Cell[42678, 838, 2552, 39, 45, "Input",ExpressionUUID->"3ecdd6ed-fa98-4b43-b4f6-5d8631895d85"],
Cell[45233, 879, 57061, 920, 586, "Output",ExpressionUUID->"eb1860f2-32d5-4f37-a57c-fd052bdbb687"]
}, Open  ]],
Cell[102309, 1802, 2625, 71, 86, "Input",ExpressionUUID->"f9ee7cd5-70e7-456c-9b5e-9a5359727b89"],
Cell[104937, 1875, 1274, 20, 45, "Input",ExpressionUUID->"ea6cd35f-7ef6-4016-bcf1-c422ebbced6e"],
Cell[CellGroupData[{
Cell[106236, 1899, 5726, 86, 86, "Input",ExpressionUUID->"37a11c79-0e11-4b53-8834-56d4bb5f3c45"],
Cell[111965, 1987, 71716, 1183, 234, "Output",ExpressionUUID->"964df6b6-e8f3-4959-aacd-1e7c170313a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183718, 3175, 9966, 222, 355, "Input",ExpressionUUID->"98796199-16be-423a-9954-5519d883d4b3"],
Cell[193687, 3399, 4780, 69, 38, "Output",ExpressionUUID->"55301f2e-cc1a-4f36-834a-e588a81f8745"],
Cell[198470, 3470, 67457, 1114, 235, "Output",ExpressionUUID->"cc149d34-9370-4e8a-ba05-81afbbef9de2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265964, 4589, 17026, 318, 486, "Input",ExpressionUUID->"bad72af6-3695-4850-b7f8-1df234a4bb32"],
Cell[282993, 4909, 486, 10, 22, "Message",ExpressionUUID->"9ec800c7-0b43-474c-947e-d0da378450e8"],
Cell[283482, 4921, 489, 10, 22, "Message",ExpressionUUID->"5b531890-ab73-47cc-9311-54bf34d0d3b0"],
Cell[283974, 4933, 490, 10, 22, "Message",ExpressionUUID->"e21409c0-b1f7-46fe-85ff-09eef6b2da68"],
Cell[284467, 4945, 482, 10, 22, "Message",ExpressionUUID->"1c19c761-02c2-4a43-8ba0-de88f9550abe"],
Cell[CellGroupData[{
Cell[284974, 4959, 148, 3, 25, "Print",ExpressionUUID->"73796a2a-a907-4a32-a3ae-8a97e358ac58"],
Cell[285125, 4964, 150, 3, 25, "Print",ExpressionUUID->"185319bc-c094-4dd8-8d47-702398c0ce67"],
Cell[285278, 4969, 152, 3, 25, "Print",ExpressionUUID->"9ad14b74-d999-4664-b78b-0dbc0d635c2f"],
Cell[285433, 4974, 154, 3, 25, "Print",ExpressionUUID->"2733ea58-7fab-49c6-944b-680e959657ed"],
Cell[285590, 4979, 151, 3, 27, "Print",ExpressionUUID->"5033e53a-892f-47b1-bf5d-d688af5d50c3"]
}, Open  ]]
}, Open  ]],
Cell[285768, 4986, 695, 12, 45, "Input",ExpressionUUID->"166dc07b-b6aa-4e17-8863-40492d1a9ab4"],
Cell[CellGroupData[{
Cell[286488, 5002, 5312, 77, 45, "Input",ExpressionUUID->"3ab47d70-f2b6-4812-be72-ee98fd16eca1"],
Cell[291803, 5081, 104451, 1748, 235, "Output",ExpressionUUID->"ca59937d-5de3-4a6b-97e2-79754ead71a9"]
}, Open  ]],
Cell[396269, 6832, 212, 3, 45, "Input",ExpressionUUID->"6861bd18-e4b7-42b8-bd0b-4ccfe963e84b"],
Cell[396484, 6837, 310, 5, 45, "Input",ExpressionUUID->"0ed0e200-8e62-4395-a6b5-ec8e8d4b5276"],
Cell[396797, 6844, 520, 10, 45, "Input",ExpressionUUID->"eb043169-a279-4e07-b51c-e7ecebec4393"],
Cell[397320, 6856, 840, 15, 45, "Input",ExpressionUUID->"4e3f6060-42f9-4ca8-82bd-d9cf1b067315"],
Cell[398163, 6873, 1384, 21, 45, "Input",ExpressionUUID->"5161df72-a8b7-426b-a11f-e5bc0293de1a"]
}
]
*)

